@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
+ *  Copyright (c) 2007, 2021, Oracle and/or its affiliates. All rights reserved.
  *  DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  *  This code is free software; you can redistribute it and/or modify it
@@ -25,8 +25,13 @@
 
 var awtScriptPath = "nbres:/org/graalvm/visualvm/modules/tracer/swing/resources/AWTTracer.btrace"
 var swingScriptPath = "nbres:/org/graalvm/visualvm/modules/tracer/swing/resources/SwingTracer.btrace"
-var btraceDeployer = typeof(Packages.net.java.btrace.visualvm.tracer.deployer.BTraceDeployer) == "function" ?
-                        Packages.net.java.btrace.visualvm.tracer.deployer.BTraceDeployer.instance() : undefined;
+var btraceDeployerClass;
+try {
+  btraceDeployerClass = Java.type("org.openjdk.btrace.visualvm.tracer.deployer.BTraceDeployer");
+} catch (e) {
+  btraceDeployerClass = null;
+}
+var btraceDeployer = btraceDeployerClass ? btraceDeployerClass.instance() : undefined;
 
 function SelfTimePercentAcc(mbean, blockName) {
     var valAcc = mbean.get("data").get(blockName).get("selfTime.percent");
