@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,18 +25,6 @@
 
 package org.graalvm.visualvm.application.views.monitor;
 
-import org.graalvm.visualvm.application.Application;
-import org.graalvm.visualvm.core.datasupport.DataRemovedListener;
-import org.graalvm.visualvm.charts.ChartFactory;
-import org.graalvm.visualvm.charts.SimpleXYChartDescriptor;
-import org.graalvm.visualvm.charts.SimpleXYChartSupport;
-import org.graalvm.visualvm.core.datasource.DataSource;
-import org.graalvm.visualvm.core.datasupport.Stateful;
-import org.graalvm.visualvm.core.ui.DataSourceView;
-import org.graalvm.visualvm.core.ui.components.DataViewComponent;
-import org.graalvm.visualvm.core.ui.components.NotSupportedDisplayer;
-import org.graalvm.visualvm.heapdump.HeapDumpSupport;
-import org.graalvm.visualvm.uisupport.HTMLTextArea;
 import java.awt.BorderLayout;
 import java.awt.Toolkit;
 import java.awt.event.ActionEvent;
@@ -52,6 +40,18 @@ import javax.swing.JPanel;
 import javax.swing.SwingUtilities;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
+import org.graalvm.visualvm.application.Application;
+import org.graalvm.visualvm.charts.ChartFactory;
+import org.graalvm.visualvm.charts.SimpleXYChartDescriptor;
+import org.graalvm.visualvm.charts.SimpleXYChartSupport;
+import org.graalvm.visualvm.core.datasource.DataSource;
+import org.graalvm.visualvm.core.datasupport.DataRemovedListener;
+import org.graalvm.visualvm.core.datasupport.Stateful;
+import org.graalvm.visualvm.core.ui.DataSourceView;
+import org.graalvm.visualvm.core.ui.components.DataViewComponent;
+import org.graalvm.visualvm.core.ui.components.NotSupportedDisplayer;
+import org.graalvm.visualvm.heapdump.HeapDumpSupport;
+import org.graalvm.visualvm.uisupport.HTMLTextArea;
 import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
 import org.openide.util.ImageUtilities;
@@ -73,7 +73,7 @@ class ApplicationMonitorView extends DataSourceView {
     private final ApplicationMonitorModel model;
     
 
-    public ApplicationMonitorView(ApplicationMonitorModel model) {
+    ApplicationMonitorView(ApplicationMonitorModel model) {
         super(model.getSource(), NbBundle.getMessage(ApplicationMonitorView.class,
                                  "LBL_Monitor"), new ImageIcon(ImageUtilities.   // NOI18N
                                  loadImage(IMAGE_PATH, true)).getImage(), 20, false);
@@ -116,9 +116,11 @@ class ApplicationMonitorView extends DataSourceView {
         dvc.addDetailsView(classesViewSupport.getDetailsView(), DataViewComponent.BOTTOM_LEFT);
 
         final ThreadsViewSupport threadsViewSupport = new ThreadsViewSupport(model);
+        final VirtualThreadsViewSupport vThreadsViewSupport = model.isVirtualThreadsMonitoringSupported() ? new VirtualThreadsViewSupport(model) : null;
         dvc.configureDetailsArea(new DataViewComponent.DetailsAreaConfiguration(NbBundle.
                 getMessage(ApplicationMonitorView.class, "LBL_Threads"), true), DataViewComponent.BOTTOM_RIGHT);   // NOI18N
         dvc.addDetailsView(threadsViewSupport.getDetailsView(), DataViewComponent.BOTTOM_RIGHT);
+        if (vThreadsViewSupport != null) dvc.addDetailsView(vThreadsViewSupport.getDetailsView(), DataViewComponent.BOTTOM_RIGHT);
 
         final Runnable refresher = new Runnable() {
             public void run() {
@@ -128,6 +130,7 @@ class ApplicationMonitorView extends DataSourceView {
                 if (permGenViewSupport != null) permGenViewSupport.refresh(model);
                 classesViewSupport.refresh(model);
                 threadsViewSupport.refresh(model);
+                if (vThreadsViewSupport != null) vThreadsViewSupport.refresh(model);
             }
         };
 
@@ -151,7 +154,7 @@ class ApplicationMonitorView extends DataSourceView {
         private JButton gcButton;
         private JButton heapDumpButton;
         
-        public MasterViewSupport(ApplicationMonitorModel model) {
+        MasterViewSupport(ApplicationMonitorModel model) {
             initComponents(model);
         }
         
@@ -261,7 +264,7 @@ class ApplicationMonitorView extends DataSourceView {
             long seconds = millis / 1000;
             String sSeconds = ((seconds < 10) ? "0" + seconds : "" + seconds); // NOI18N
             
-            if (sHours.length() == 0) {
+            if (sHours.isEmpty()) {
                  return NbBundle.getMessage(ApplicationMonitorView.class, "FORMAT_ms", // NOI18N
                                             new Object[] { sMinutes, sSeconds });
             } else {
@@ -289,7 +292,7 @@ class ApplicationMonitorView extends DataSourceView {
         private SimpleXYChartSupport chartSupport;
 
 
-        public CpuViewSupport(ApplicationMonitorModel model) {
+        CpuViewSupport(ApplicationMonitorModel model) {
             initModels(model);
             initComponents();
         }
@@ -394,7 +397,7 @@ class ApplicationMonitorView extends DataSourceView {
 
         private SimpleXYChartSupport chartSupport;
 
-        public HeapViewSupport(ApplicationMonitorModel model) {
+        HeapViewSupport(ApplicationMonitorModel model) {
             initModels(model);
             initComponents();
         }
@@ -434,6 +437,7 @@ class ApplicationMonitorView extends DataSourceView {
 
                 chartDescriptor.addLineFillItems(HEAP_SIZE_LEG, USED_HEAP_LEG);
                 chartDescriptor.setDetailsItems(new String[] { HEAP_SIZE, USED_HEAP, MAX_HEAP });
+                chartDescriptor.setLimitYValue(model.getMaxHeap());
 
                 chartSupport = ChartFactory.createSimpleXYChart(chartDescriptor);
                 model.registerHeapChartSupport(chartSupport);
@@ -468,7 +472,7 @@ class ApplicationMonitorView extends DataSourceView {
 
         private SimpleXYChartSupport chartSupport;
 
-        public PermGenViewSupport(ApplicationMonitorModel model) {
+        PermGenViewSupport(ApplicationMonitorModel model) {
             initModels(model);
             initComponents();
         }
@@ -502,12 +506,16 @@ class ApplicationMonitorView extends DataSourceView {
                 String USED_PERM = NbBundle.getMessage(ApplicationMonitorView.class, "LBL_Used_PermGen");  // NOI18N
                 String USED_PERM_LEG = NbBundle.getMessage(ApplicationMonitorView.class, "LBL_Used_PermGen_leg", permgenName);  // NOI18N
                 String MAX_PERM = NbBundle.getMessage(ApplicationMonitorView.class, "LBL_Max_PermGen_size");   // NOI18N
+                long permgenMax = model.getPermgenMax();
 
                 SimpleXYChartDescriptor chartDescriptor =
                         SimpleXYChartDescriptor.bytes(10 * 1024 * 1024, false, model.getChartCache());
 
                 chartDescriptor.addLineFillItems(PERM_SIZE_LEG, USED_PERM_LEG);
                 chartDescriptor.setDetailsItems(new String[] { PERM_SIZE, USED_PERM, MAX_PERM });
+                if (permgenMax != -1) {
+                    chartDescriptor.setLimitYValue(permgenMax);
+                }
 
                 chartSupport = ChartFactory.createSimpleXYChart(chartDescriptor);
                 model.registerPermGenChartSupport(chartSupport);
@@ -548,7 +556,7 @@ class ApplicationMonitorView extends DataSourceView {
 
         private SimpleXYChartSupport chartSupport;
 
-        public ClassesViewSupport(ApplicationMonitorModel model) {
+        ClassesViewSupport(ApplicationMonitorModel model) {
             initModels(model);
             initComponents();
         }
@@ -624,7 +632,7 @@ class ApplicationMonitorView extends DataSourceView {
 
         private SimpleXYChartSupport chartSupport;
 
-        public ThreadsViewSupport(ApplicationMonitorModel model) {
+        ThreadsViewSupport(ApplicationMonitorModel model) {
             initModels(model);
             initComponents();
         }
@@ -683,4 +691,72 @@ class ApplicationMonitorView extends DataSourceView {
 
     }
 
+    // --- Virtual Threads -------------------------------------------------------------
+
+    private static class VirtualThreadsViewSupport extends JPanel  {
+
+        private static final String PARALLELISM = NbBundle.getMessage(ApplicationMonitorView.class, "LBL_Parallelism");   // NOI18N
+        private static final String POOL_SIZE = NbBundle.getMessage(ApplicationMonitorView.class, "LBL_Pool_size");  // NOI18N
+        private static final String MOUNTED_VT_COUNT = NbBundle.getMessage(ApplicationMonitorView.class, "LBL_Mounted_virtual_thread_count");   // NOI18N
+        private static final String MOUNTED_VT_COUNT_LEG = NbBundle.getMessage(ApplicationMonitorView.class, "LBL_Mounted_virtual_thread_count_leg");   // NOI18N
+        private static final String QUEUED_VT_COUNT = NbBundle.getMessage(ApplicationMonitorView.class, "LBL_Queued_virtual_thread_count");// NOI18N
+        private static final String QUEUED_VT_COUNT_LEG = NbBundle.getMessage(ApplicationMonitorView.class, "LBL_Queued_virtual_thread_count_leg");// NOI18N
+        private static final String VIRTUAL_THREADS = NbBundle.getMessage(ApplicationMonitorView.class, "LBL_Virtual_Threads");   // NOI18N
+
+        private boolean liveModel;
+        private boolean virtualThreadsMonitoringSupported;
+
+        private SimpleXYChartSupport chartSupport;
+
+
+        VirtualThreadsViewSupport(ApplicationMonitorModel model) {
+            initModels(model);
+            initComponents();
+        }
+
+        public DataViewComponent.DetailsView getDetailsView() {
+            return new DataViewComponent.DetailsView(VIRTUAL_THREADS, null, 10, this, null);
+        }
+
+        public void refresh(ApplicationMonitorModel model) {
+                int parallelism = model.getParallelism();
+                int poolSize = model.getPoolSize();
+                int mountedVirtualThreadCount = model.getMountedVirtualThreadCount();
+                long queuedVirtualThreadCount = model.getQueuedVirtualThreadCount();
+
+                if (liveModel)
+                        chartSupport.addValues(model.getTimestamp(), new long[] { mountedVirtualThreadCount, queuedVirtualThreadCount });
+                chartSupport.updateDetails(new String[] { chartSupport.formatDecimal(parallelism),
+                                                          chartSupport.formatDecimal(poolSize),
+                                                          chartSupport.formatDecimal(mountedVirtualThreadCount),
+                                                          chartSupport.formatDecimal(queuedVirtualThreadCount) });
+        }
+
+        private void initModels(ApplicationMonitorModel model) {
+            liveModel = model.isLive();
+            virtualThreadsMonitoringSupported = model.isVirtualThreadsMonitoringSupported();
+
+            if (virtualThreadsMonitoringSupported) {
+                SimpleXYChartDescriptor chartDescriptor =
+                        SimpleXYChartDescriptor.decimal(3, false, model.getChartCache());
+
+                chartDescriptor.addLineItems(MOUNTED_VT_COUNT_LEG, QUEUED_VT_COUNT_LEG);
+                chartDescriptor.setDetailsItems(new String[] { PARALLELISM, POOL_SIZE,
+                                                               MOUNTED_VT_COUNT, QUEUED_VT_COUNT });
+
+                chartSupport = ChartFactory.createSimpleXYChart(chartDescriptor);
+                model.registerThreadsChartSupport(chartSupport);
+
+                chartSupport.setZoomingEnabled(!liveModel);
+            }
+        }
+
+        private void initComponents() {
+            setLayout(new BorderLayout());
+            setOpaque(false);
+
+            add(chartSupport.getChart(), BorderLayout.CENTER);
+            chartSupport.updateDetails(new String[] { UNKNOWN, UNKNOWN, UNKNOWN, UNKNOWN });
+        }
+    }
 }
