@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,23 +25,6 @@
 
 package org.graalvm.visualvm.application.views.threads;
 
-import org.graalvm.visualvm.application.Application;
-import org.graalvm.visualvm.core.datasupport.DataRemovedListener;
-import org.graalvm.visualvm.application.jvm.Jvm;
-import org.graalvm.visualvm.application.jvm.JvmFactory;
-import org.graalvm.visualvm.core.datasource.DataSource;
-import org.graalvm.visualvm.core.datasupport.Stateful;
-import org.graalvm.visualvm.core.options.GlobalPreferences;
-import org.graalvm.visualvm.core.ui.DataSourceView;
-import org.graalvm.visualvm.core.ui.components.DataViewComponent;
-import org.graalvm.visualvm.threaddump.ThreadDumpSupport;
-import org.graalvm.visualvm.tools.jmx.JmxModel;
-import org.graalvm.visualvm.tools.jmx.JmxModel.ConnectionState;
-import org.graalvm.visualvm.tools.jmx.JmxModelFactory;
-import org.graalvm.visualvm.tools.jmx.JvmMXBeans;
-import org.graalvm.visualvm.tools.jmx.JvmMXBeansFactory;
-import org.graalvm.visualvm.tools.jmx.MBeanCacheListener;
-import org.graalvm.visualvm.uisupport.HTMLTextArea;
 import java.awt.BorderLayout;
 import java.awt.Color;
 import java.awt.Toolkit;
@@ -59,13 +42,31 @@ import javax.swing.JComponent;
 import javax.swing.JLabel;
 import javax.swing.JPanel;
 import javax.swing.SwingUtilities;
+import org.graalvm.visualvm.application.Application;
+import org.graalvm.visualvm.application.jvm.Jvm;
+import org.graalvm.visualvm.application.jvm.JvmFactory;
+import org.graalvm.visualvm.core.datasource.DataSource;
+import org.graalvm.visualvm.core.datasupport.DataRemovedListener;
+import org.graalvm.visualvm.core.datasupport.Stateful;
+import org.graalvm.visualvm.core.options.GlobalPreferences;
+import org.graalvm.visualvm.core.ui.DataSourceView;
+import org.graalvm.visualvm.core.ui.components.DataViewComponent;
+import org.graalvm.visualvm.lib.profiler.api.ActionsSupport;
+import org.graalvm.visualvm.lib.profiler.api.ProfilerDialogs;
 import org.graalvm.visualvm.lib.ui.components.ProfilerToolbar;
 import org.graalvm.visualvm.lib.ui.swing.ActionPopupButton;
+import org.graalvm.visualvm.lib.ui.swing.FilterUtils;
 import org.graalvm.visualvm.lib.ui.swing.GrayLabel;
 import org.graalvm.visualvm.lib.ui.swing.SearchUtils;
 import org.graalvm.visualvm.lib.ui.threads.ThreadsPanel;
-import org.graalvm.visualvm.lib.profiler.api.ActionsSupport;
-import org.graalvm.visualvm.lib.profiler.api.ProfilerDialogs;
+import org.graalvm.visualvm.threaddump.ThreadDumpSupport;
+import org.graalvm.visualvm.tools.jmx.JmxModel;
+import org.graalvm.visualvm.tools.jmx.JmxModel.ConnectionState;
+import org.graalvm.visualvm.tools.jmx.JmxModelFactory;
+import org.graalvm.visualvm.tools.jmx.JvmMXBeans;
+import org.graalvm.visualvm.tools.jmx.JvmMXBeansFactory;
+import org.graalvm.visualvm.tools.jmx.MBeanCacheListener;
+import org.graalvm.visualvm.uisupport.HTMLTextArea;
 import org.openide.util.ImageUtilities;
 import org.openide.util.NbBundle;
 import org.openide.util.WeakListeners;
@@ -94,13 +95,13 @@ class ApplicationThreadsView extends DataSourceView implements DataRemovedListen
         if (ds instanceof Application) {
             Application application = (Application)ds;
             Jvm jvm = JvmFactory.getJVMFor(application);
-            takeThreadDumpSupported = jvm == null ? false : jvm.isTakeThreadDumpSupported();
+            takeThreadDumpSupported = jvm.isTakeThreadDumpSupported();
             threadsManager = null;
             JmxModel jmxModel = JmxModelFactory.getJmxModelFor(application);
             if (jmxModel != null && jmxModel.getConnectionState() == ConnectionState.CONNECTED) {
                 mxbeans = JvmMXBeansFactory.getJvmMXBeans(jmxModel, GlobalPreferences.sharedInstance().getThreadsPoll() * 1000);
                 if (mxbeans != null) {
-                    ThreadMXBeanDataManager threadsMXManager = new ThreadMXBeanDataManager(mxbeans.getThreadMXBean());
+                    ThreadMXBeanDataManager threadsMXManager = new ThreadMXBeanDataManager(application, mxbeans.getThreadMXBean());
                     
                     threadsMXManager.addPropertyChangeListener(new PropertyChangeListener() {
                         public void propertyChange(PropertyChangeEvent evt) {
@@ -132,6 +133,7 @@ class ApplicationThreadsView extends DataSourceView implements DataRemovedListen
         if (mxbeans != null) {
             mxbeans.removeMBeanCacheListener(listener);
             mxbeans = null;
+            threadsManager.cleanup();
         }
     }
 
@@ -346,7 +348,7 @@ class ApplicationThreadsView extends DataSourceView implements DataRemovedListen
             InputMap inputMap = getInputMap(JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);
             ActionMap actionMap = getActionMap();
 
-            final String filterKey = org.graalvm.visualvm.lib.ui.swing.FilterUtils.FILTER_ACTION_KEY;
+            final String filterKey = FilterUtils.FILTER_ACTION_KEY;
             Action filterAction = new AbstractAction() {
                 public void actionPerformed(ActionEvent e) {
                     Action action = threadsPanel.getActionMap().get(filterKey);
