@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,8 +25,6 @@
 
 package org.graalvm.visualvm.modules.appui.options;
 
-import org.graalvm.visualvm.core.options.UISupport;
-import org.graalvm.visualvm.core.ui.components.SectionSeparator;
 import java.awt.BorderLayout;
 import java.awt.Color;
 import java.awt.Component;
@@ -60,6 +58,12 @@ import javax.swing.event.ListSelectionListener;
 import javax.swing.table.AbstractTableModel;
 import javax.swing.table.DefaultTableModel;
 import javax.swing.table.TableModel;
+import org.graalvm.visualvm.core.options.UISupport;
+import org.graalvm.visualvm.core.ui.components.SectionSeparator;
+import org.graalvm.visualvm.lib.profiler.api.ProfilerIDESettings;
+import org.graalvm.visualvm.lib.profiler.api.icons.GeneralIcons;
+import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
+import org.graalvm.visualvm.lib.profiler.api.icons.ProfilerIcons;
 import org.graalvm.visualvm.lib.ui.results.ColoredFilter;
 import org.graalvm.visualvm.lib.ui.results.PackageColorer;
 import org.graalvm.visualvm.lib.ui.swing.ProfilerTable;
@@ -67,10 +71,6 @@ import org.graalvm.visualvm.lib.ui.swing.ProfilerTableContainer;
 import org.graalvm.visualvm.lib.ui.swing.SmallButton;
 import org.graalvm.visualvm.lib.ui.swing.renderer.JavaNameRenderer;
 import org.graalvm.visualvm.lib.ui.swing.renderer.LabelRenderer;
-import org.graalvm.visualvm.lib.profiler.api.ProfilerIDESettings;
-import org.graalvm.visualvm.lib.profiler.api.icons.GeneralIcons;
-import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
-import org.graalvm.visualvm.lib.profiler.api.icons.ProfilerIcons;
 import org.openide.DialogDescriptor;
 import org.openide.DialogDisplayer;
 import org.openide.awt.Mnemonics;
@@ -82,7 +82,7 @@ import org.openide.util.NbBundle;
  */
 @NbBundle.Messages({
     "FiltersOptionsPanel_Name=Filters",
-    "FiltersOptionsPanel_ColoringResults=&Use defined filters for coloring results (Sampler, Profiler and Heap Viewer)",
+    "FiltersOptionsPanel_ColoringResults=&Use defined filters for coloring results (Sampler, Profiler, Heap Viewer, JFR Viewer, etc.)",
     "FiltersOptionsPanel_DefinedFilters=Defined &Filters:",
     "FiltersOptionsPanel_AddFilter=Add new filter",
     "FiltersOptionsPanel_EditFilter=Edit selected filter",
@@ -93,6 +93,9 @@ import org.openide.util.NbBundle;
     "FiltersOptionsPanel_ColumnPackages=Packages",
     "FiltersOptionsPanel_ColumnColor=Color",
     "ColorCustomizer_DefaultColor=Default color",
+    "# {0} - red",
+    "# {1} - green",
+    "# {2} - blue",
     "ColorCustomizer_CustomColor=Custom color [{0},{1},{2}]",
     "ColorCustomizer_Name=Name:",
     "ColorCustomizer_Color=Color:",
@@ -104,13 +107,13 @@ import org.openide.util.NbBundle;
 })
 final class FiltersOptionsPanel extends JPanel {
     
-    private final List<ColoredFilter> colors = new ArrayList();
+    private final List<ColoredFilter> colors = new ArrayList<>();
     private final ColorsTableModel colorsModel = new ColorsTableModel();
     
     private JCheckBox coloringChoice;
     
     
-    public FiltersOptionsPanel() {
+    FiltersOptionsPanel() {
         initUI();
     }
 
