@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -27,10 +27,6 @@ package org.graalvm.visualvm.modules.appui.options;
 
 import java.awt.Cursor;
 import java.awt.Dimension;
-import org.graalvm.visualvm.core.options.UISupport;
-import org.graalvm.visualvm.core.ui.components.SectionSeparator;
-import org.graalvm.visualvm.core.ui.components.Spacer;
-import org.graalvm.visualvm.uisupport.JExtendedSpinner;
 import java.awt.GridBagConstraints;
 import java.awt.GridBagLayout;
 import java.awt.Insets;
@@ -56,6 +52,10 @@ import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 import javax.swing.event.DocumentEvent;
 import javax.swing.event.DocumentListener;
+import org.graalvm.visualvm.core.options.UISupport;
+import org.graalvm.visualvm.core.ui.components.SectionSeparator;
+import org.graalvm.visualvm.core.ui.components.Spacer;
+import org.graalvm.visualvm.uisupport.JExtendedSpinner;
 import org.netbeans.modules.autoupdate.ui.api.PluginManager;
 import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
@@ -304,7 +304,7 @@ class NetworkOptionsPanel extends JPanel {
         manualSettingsPanel.add(httpProxyPortLabel, c);
 
         httpProxySpinnerModel = new SpinnerNumberModel(0, 0, 65535, 1);
-        httpProxyPortSpinner = new JExtendedSpinner(httpProxySpinnerModel);
+        httpProxyPortSpinner = createJSpinner(httpProxySpinnerModel);
         httpProxyPortLabel.setLabelFor(httpProxyPortSpinner);
         c = new GridBagConstraints();
         c.gridx = 3;
@@ -359,7 +359,7 @@ class NetworkOptionsPanel extends JPanel {
         manualSettingsPanel.add(httpsProxyPortLabel, c);
 
         httpsProxySpinnerModel = new SpinnerNumberModel(0, 0, 65535, 1);
-        httpsProxyPortSpinner = new JExtendedSpinner(httpsProxySpinnerModel);
+        httpsProxyPortSpinner = createJSpinner(httpsProxySpinnerModel);
         httpsProxyPortLabel.setLabelFor(httpsProxyPortSpinner);
         c = new GridBagConstraints();
         c.gridx = 3;
@@ -402,7 +402,7 @@ class NetworkOptionsPanel extends JPanel {
         manualSettingsPanel.add(socksProxyPortLabel, c);
 
         socksProxySpinnerModel = new SpinnerNumberModel(0, 0, 65535, 1);
-        socksProxyPortSpinner = new JExtendedSpinner(socksProxySpinnerModel);
+        socksProxyPortSpinner = createJSpinner(socksProxySpinnerModel);
         socksProxyPortLabel.setLabelFor(socksProxyPortSpinner);
         c = new GridBagConstraints();
         c.gridx = 3;
@@ -523,6 +523,13 @@ class NetworkOptionsPanel extends JPanel {
         updateJSEngineNotifier(systemProxyRadio.isSelected());
     }
 
+    private JExtendedSpinner createJSpinner(SpinnerModel model) {
+        JExtendedSpinner spinner = new JExtendedSpinner(model);
+        JSpinner.NumberEditor seditor = (JSpinner.NumberEditor)spinner.getEditor();
+        seditor.getFormat().setGroupingUsed(false);
+        return spinner;
+    }
+
     private void initListeners() {
         manualProxyRadio.addChangeListener(new ChangeListener() {
             public void stateChanged(ChangeEvent e) {
