@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -52,6 +52,8 @@ import javax.swing.JPanel;
 import javax.swing.JScrollBar;
 import javax.swing.SwingConstants;
 import javax.swing.plaf.LabelUI;
+import org.graalvm.visualvm.lib.charts.ChartContext;
+import org.graalvm.visualvm.lib.charts.ChartDecorator;
 import org.graalvm.visualvm.lib.charts.ChartItem;
 import org.graalvm.visualvm.lib.charts.ChartItemChange;
 import org.graalvm.visualvm.lib.charts.ChartSelectionModel;
@@ -60,11 +62,13 @@ import org.graalvm.visualvm.lib.charts.ItemsModel;
 import org.graalvm.visualvm.lib.charts.axis.AxisComponent;
 import org.graalvm.visualvm.lib.charts.axis.AxisMarksPainter;
 import org.graalvm.visualvm.lib.charts.axis.BytesMarksPainter;
+import org.graalvm.visualvm.lib.charts.axis.BitsPerSecMarksPainter;
 import org.graalvm.visualvm.lib.charts.axis.TimeAxisUtils;
 import org.graalvm.visualvm.lib.charts.axis.TimeMarksPainter;
 import org.graalvm.visualvm.lib.charts.axis.TimelineMarksComputer;
 import org.graalvm.visualvm.lib.charts.swing.CrossBorderLayout;
 import org.graalvm.visualvm.lib.charts.swing.LongRect;
+import org.graalvm.visualvm.lib.charts.swing.Utils;
 import org.graalvm.visualvm.lib.charts.xy.BytesXYItemMarksComputer;
 import org.graalvm.visualvm.lib.charts.xy.DecimalXYItemMarksComputer;
 import org.graalvm.visualvm.lib.charts.xy.XYItemPainter;
@@ -83,6 +87,7 @@ public class SimpleXYChartUtils {
     public static final int TYPE_DECIMAL = 0;
     public static final int TYPE_BYTES = 1;
     public static final int TYPE_PERCENT = 2;
+    public static final int TYPE_BITS_PER_SEC = 3;
 
 
     // --- Private constants ---------------------------------------------------
@@ -125,7 +130,7 @@ public class SimpleXYChartUtils {
         LEGEND_HEIGHT = -1;
         DETAILS_HEIGHT_THRESHOLD = 180;
 
-        FORMATS = new HashMap();
+        FORMATS = new HashMap<>();
     }
     
     
@@ -173,7 +178,8 @@ public class SimpleXYChartUtils {
                                            boolean supportsZooming, double chartFactor,
                                            NumberFormat customFormat, XYStorage storage,
                                            SynchronousXYItemsModel itemsModel,
-                                           XYPaintersModel paintersModel) {
+                                           XYPaintersModel paintersModel,
+                                           long limitYValue) {
 
         // Chart
         final boolean hasAxisLabel = xAxisDescription != null || yAxisDescription != null;
@@ -204,6 +210,9 @@ public class SimpleXYChartUtils {
                                        2500, initialYMargin));
         
         chart.addPreDecorator(new XYBackground());
+        if (limitYValue != 0) {
+            chart.addPreDecorator(createMaxHeapDecorator(limitYValue));
+        }
         
         // Horizontal axis
         TimelineMarksComputer hComputer = new TimelineMarksComputer(storage,
@@ -239,6 +248,16 @@ public class SimpleXYChartUtils {
             vAxis = new XYAxisComponent(chart, vComputer, customizeMarksPainter(
                          new BytesMarksPainter()), SwingConstants.WEST,
                          AxisComponent.MESH_FOREGROUND);
+        } else if (chartType == TYPE_BITS_PER_SEC) {
+            SynchronousXYItem item = itemsModel.getItem(0);
+            XYItemPainter painter = (XYItemPainter)paintersModel.getPainter(item);
+            BytesXYItemMarksComputer vComputer = new BytesXYItemMarksComputer(
+                         item, painter, chart.getChartContext(),
+                         SwingConstants.VERTICAL) {
+                protected int getMinMarksDistance() { return VALUES_SPACING; }
+            };
+            vAxis = new XYAxisComponent(chart, vComputer, customizeMarksPainter(new BitsPerSecMarksPainter()), SwingConstants.WEST,
+                         AxisComponent.MESH_FOREGROUND);
         } else {
             SynchronousXYItem item = itemsModel.getItem(0);
             XYItemPainter painter = (XYItemPainter)paintersModel.getPainter(item);
@@ -506,6 +525,7 @@ public class SimpleXYChartUtils {
                 switch (chartType) {
                     case TYPE_BYTES  : return formatBytes((long)value);
                     case TYPE_PERCENT: return formatPercent(value);
+                    case TYPE_BITS_PER_SEC  : return formatBitsPerSec((long)value);
                     default:           return formatDecimal(value, customFormat);
                 }
             }
@@ -533,6 +553,12 @@ public class SimpleXYChartUtils {
         return MessageFormat.format(bytesFormat, new Object[] { formatDecimal(value) });
     }
 
+    public static String formatBitsPerSec(long value) {
+        String bpsFormat = NbBundle.getMessage(SimpleXYChartUtils.class,
+                                                "SimpleXYChartUtils_BitsPerSecFormat"); // NOI18N
+        return MessageFormat.format(bpsFormat, new Object[] { formatDecimal(value) });
+    }
+
     public static String formatPercent(double value) {
         return PERCENT_FORMATTER.format(value / 100);
     }
@@ -543,11 +569,11 @@ public class SimpleXYChartUtils {
     }
 
     public static Font smallerFont(Font font) {
-        return new Font(font.getName(), font.getStyle(), font.getSize() - 2);
+        return font.deriveFont((float)font.getSize() - 2);
     }
 
     public static Font boldFont(Font font) {
-        return new Font(font.getName(), Font.BOLD, font.getSize());
+        return font.deriveFont(Font.BOLD);
     }
 
 
@@ -617,6 +643,26 @@ public class SimpleXYChartUtils {
         };
     }
 
+    private static final Color  HEAP_LIMIT_FILL_COLOR = !UISupport.isDarkResultsBackground() ?
+                               new Color(220, 220, 220) : new Color(100, 100, 100);
+
+    private static ChartDecorator createMaxHeapDecorator(final long limitYValue) {
+        return new ChartDecorator() {
+            public void paint(Graphics2D g, Rectangle dirtyArea,
+                              ChartContext context) {
+
+                int limitHeight = Utils.checkedInt(context.getViewY(limitYValue));
+                if (limitHeight <= context.getViewportHeight()) {
+                    g.setColor(HEAP_LIMIT_FILL_COLOR);
+                    if (context.isBottomBased())
+                        g.fillRect(0, 0, context.getViewportWidth(), limitHeight);
+                    else
+                        g.fillRect(0, limitHeight, context.getViewportWidth(),
+                                   context.getViewportHeight() - limitHeight);
+                }
+            }
+        };
+    }
 
     // --- DetailsHandle -------------------------------------------------------
 
@@ -633,7 +679,7 @@ public class SimpleXYChartUtils {
 
         private final JCheckBox renderer;
 
-        public IconCheckBox(String text, Icon icon, boolean selected) {
+        IconCheckBox(String text, Icon icon, boolean selected) {
             renderer = new JCheckBox(text, icon) {
                 public boolean hasFocus() {
                     return IconCheckBox.this.hasFocus();
