@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -41,7 +41,6 @@ import java.util.logging.Logger;
 import javax.swing.SwingUtilities;
 import org.graalvm.visualvm.core.VisualVM;
 import org.netbeans.api.progress.ProgressHandle;
-import org.netbeans.api.progress.ProgressHandleFactory;
 import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
 
@@ -156,7 +155,7 @@ public final class DataSourceWindowManager {
         synchronized (windowListeners) {
             List<DataSourceWindowListener> listeners = windowListeners.get(dataSource);
             if (listeners != null)
-                for (DataSourceWindowListener listener : new ArrayList<DataSourceWindowListener>(listeners))
+                for (DataSourceWindowListener listener : new ArrayList<>(listeners))
                     listener.windowOpened(dataSource);
         }
     }
@@ -165,7 +164,7 @@ public final class DataSourceWindowManager {
         synchronized (windowListeners) {
             List<DataSourceWindowListener> listeners = windowListeners.get(dataSource);
             if (listeners != null)
-                for (DataSourceWindowListener listener : new ArrayList<DataSourceWindowListener>(listeners))
+                for (DataSourceWindowListener listener : new ArrayList<>(listeners))
                     listener.windowClosed(dataSource);
         }
     }
@@ -234,7 +233,7 @@ public final class DataSourceWindowManager {
         final boolean wasOpened = window[0] != null;
         
         final ProgressHandle pHandle = !wasOpened || reloadingView ?
-            ProgressHandleFactory.createHandle(NbBundle.getMessage(DataSourceWindowManager.class, "LBL_Opening",    // NOI18N
+            ProgressHandle.createHandle(NbBundle.getMessage(DataSourceWindowManager.class, "LBL_Opening",    // NOI18N
             DataSourceDescriptorFactory.getDescriptor(dataSource).getName())) : null;
         
         try {
