@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -82,6 +82,7 @@ import org.openide.windows.WindowManager;
     "RQueries_PopupSaveNew=Save As New...",
     "RQueries_PopupSaveFile=Save To New File...",
     "RQueries_LoadExternalCaption=Load External R Script",
+    "# {0} - R files",
     "RQueries_RFileFilter=R Script Files ({0})",
     "RQueries_InvalidScript=Invalid R script file.",
     "RQueries_LoadFailed=Failed to load R script.",
@@ -326,9 +327,7 @@ final class RQueries {
                     SwingUtilities.invokeLater(new Runnable() {
                         public void run() {
                             List<Query> l = customQueries.list();
-                            Iterator<Query> i = l.iterator();
-                            while (i.hasNext()) {
-                                Query q = i.next();
+                            for (Query q : l) {
                                 if (sameQuery(query, q)) {
                                     Query qq = RQueryCustomizer.editCustomizer(query, ""); // NOI18N
                                     if (qq == null) return;
@@ -371,7 +370,7 @@ final class RQueries {
         
         popup.add(new JMenuItem(Bundle.RQueries_PopupDeleteAllCustom()) {
             protected void fireActionPerformed(ActionEvent e) {
-                customQueries.set(Collections.EMPTY_LIST);
+                customQueries.set(Collections.emptyList());
             }
         });
     }
@@ -443,7 +442,7 @@ final class RQueries {
                             public void run() {
                                 handler.querySelected(query);
                         
-                                if (externalQueries == null) externalQueries = new ArrayList(EXTERNAL_QUERIES_CACHE);
+                                if (externalQueries == null) externalQueries = new ArrayList<>(EXTERNAL_QUERIES_CACHE);
                                 if (containsQuery(externalQueries, query)) return;
 
                                 if (externalQueries.size() == EXTERNAL_QUERIES_CACHE)
@@ -530,7 +529,7 @@ final class RQueries {
                         public void run() {
                             if (handler != null) handler.querySelected(query);
 
-                            if (externalQueries == null) externalQueries = new ArrayList(EXTERNAL_QUERIES_CACHE);
+                            if (externalQueries == null) externalQueries = new ArrayList<>(EXTERNAL_QUERIES_CACHE);
                             if (containsQuery(externalQueries, query)) return;
 
                             if (externalQueries.size() == EXTERNAL_QUERIES_CACHE)
@@ -617,7 +616,7 @@ final class RQueries {
     
     private static class PopupSeparator extends JPanel {
     
-        public PopupSeparator(String text) {
+        PopupSeparator(String text) {
             setLayout(new BorderLayout());
             setOpaque(false);
 
@@ -752,7 +751,7 @@ final class RQueries {
             String normalizedString = null;
             if (string != null) {
                 normalizedString = string.trim();
-                if (normalizedString.length() == 0) normalizedString = null;
+                if (normalizedString.isEmpty()) normalizedString = null;
             }
             return normalizedString;
         }
