@@ -58,6 +58,7 @@ public class DynamicObject extends TruffleObject.InstanceBased {
     private static final String ENTERPRISE_PACKAGE = "com.oracle.truffle.object.enterprise"; // NOI18N
     private static final String ENTERPRISE_LOCATION_TOP_CLASS = ENTERPRISE_PACKAGE+".EnterpriseLocations"; // NOI18N
     private static final String ENTERPRISE_FIELD_LOCATION_FQN = ENTERPRISE_LOCATION_TOP_CLASS+"$FieldLocation"; // NOI18N
+    private static final String ENTERPRISE_FIELD_INFO_FQN = ENTERPRISE_PACKAGE + ".EnterpriseLayout$FieldInfo"; // NOI18N
     private static final String PROPERTY_MAP_FQN = "com.oracle.truffle.object.ConsListPropertyMap"; // NOI18N
     private static final String TRIE_PROPERTY_MAP_FQN = "com.oracle.truffle.object.TriePropertyMap"; // NOI18N
     private static final String PROPERTY_FQN = "com.oracle.truffle.object.PropertyImpl"; // NOI18N
@@ -434,6 +435,24 @@ public class DynamicObject extends TruffleObject.InstanceBased {
         return isSubClassOf(dynObj, ENTERPRISE_FIELD_LOCATION_FQN);
     }
 
+    private static boolean isEterpriseFieldInfoObjSubClass(Instance dynObj) {
+        if (dynObj != null)
+            return ENTERPRISE_FIELD_INFO_FQN.equals(dynObj.getJavaClass().getName());
+        return false;
+    }
+
+    private static boolean hasFieldInfo(Instance loc) {
+        for (FieldValue fv : loc.getFieldValues()) {
+            if (fv instanceof ObjectFieldValue) {
+                Instance fi = ((ObjectFieldValue)fv).getInstance();
+                if (isEterpriseFieldInfoObjSubClass(fi)) {
+                    return true;
+                }
+            }
+        }
+        return false;
+    }
+
     private static class Property implements Field {
 
         Instance property;
@@ -758,7 +777,7 @@ public class DynamicObject extends TruffleObject.InstanceBased {
                 arr =  (PrimitiveArrayInstance) dynamicObject.getValueOfField("extVal");    // NOI18N
             } else {
                 ObjectFieldValue arrayVal = (ObjectFieldValue) getValueImpl(actualLoc, dynamicObject);
-                arr = (PrimitiveArrayInstance) ((ObjectFieldValue)arrayVal).getInstance();
+                arr = (PrimitiveArrayInstance)arrayVal.getInstance();
             }
             return arr;
         }
@@ -841,7 +860,7 @@ public class DynamicObject extends TruffleObject.InstanceBased {
                 Instance actualLoc = (Instance) loc.getValueOfField("arrayLocation");   // NOI18N
                 Boolean allowInt = (Boolean) loc.getValueOfField("allowInt");   // NOI18N
 
-                return getObfuscatedEnterpriseArrayLocation(dynamicObject, loc, index, actualLoc, allowInt);
+                return getObfuscatedEnterpriseArrayLocation(dynamicObject, index, actualLoc, allowInt);
             }
             if (loc.getValueOfField("index") != null && loc.getValueOfField("offset") != null) {    // NOI18N
                 Integer index = (Integer)loc.getValueOfField("index");   // NOI18N
@@ -874,6 +893,31 @@ public class DynamicObject extends TruffleObject.InstanceBased {
                     return getObfuscatedEnterpriseFieldLocation(dynamicObject, loc, locIndex, locType, locAllowInt);
                 }
             }
+            if (hasFieldInfo(loc)) {
+                Integer locIndex = null;
+                Instance finfo = null;
+                Boolean locAllowInt = null;
+
+                for (Object obj : fields) {
+                    FieldValue fv = (FieldValue) obj;
+                    Field f = fv.getField();
+                    String typeName = f.getType().getName();
+
+                    if ("object".equals(typeName)) {   // NOI18N
+                        Instance val = ((ObjectFieldValue)fv).getInstance();
+                        if (isEterpriseFieldInfoObjSubClass(val)) {
+                            finfo = val;
+                        }
+                    } else if ("boolean".equals(typeName) && fields.size()==3 && f.getDeclaringClass().getSubClasses().size()==1) {
+                        locAllowInt = (Boolean) loc.getValueOfField(f.getName());
+                    } else if ("int".equals(typeName)) {   // NOI18N
+                        locIndex = (Integer) loc.getValueOfField(f.getName());
+                    }
+                }
+                if (locIndex != null && finfo != null) {
+                    return getObfuscatedEnterpriseFieldLocation(dynamicObject, loc, locIndex, finfo, locAllowInt);
+                }
+            }
             if (fields.size() >= 2) {
                 // ArrayLocation
                 Integer locIndex = null;
@@ -890,30 +934,33 @@ public class DynamicObject extends TruffleObject.InstanceBased {
                         if (isLocationObjSubClass(val)) {
                             locArrayLocation = val;
                         }
-                    }
-                    if ("boolean".equals(typeName) && fields.size()==3 && f.getDeclaringClass().getSubClasses().size()==2) {
+                    } else if ("boolean".equals(typeName) && fields.size()==3 && f.getDeclaringClass().getSubClasses().size()==2) {
                         locAllowInt = (Boolean) loc.getValueOfField(f.getName());
-                    }
-                    if ("int".equals(typeName)) {   // NOI18N
+                    } else if ("int".equals(typeName)) {   // NOI18N
                         locIndex = (Integer) loc.getValueOfField(f.getName());
                     }
                 }
-                if (locIndex != null && locArrayLocation != null) {
-                    return getObfuscatedEnterpriseArrayLocation(dynamicObject, loc, locIndex, locArrayLocation, locAllowInt);
+                if (locIndex != null) {
+                    return getObfuscatedEnterpriseArrayLocation(dynamicObject, locIndex, locArrayLocation, locAllowInt);
                 }
             }
             if (fields.size() == 1) {
                 // obfuscated static property location
                 isStatic = true;
-                FieldValue staticFieldVal = (FieldValue) fields.get(0);
+                FieldValue staticFieldVal = fields.get(0);
                 return createFieldValue(dynamicObject, staticFieldVal);
             }
             return null;
         }
 
-        private FieldValue getObfuscatedEnterpriseArrayLocation(Instance dynamicObject, Instance loc, Integer index, Instance actualLoc, Boolean allowInt) {
-            ObjectFieldValue arrayVal = (ObjectFieldValue) getValueImpl(actualLoc, dynamicObject);
-            Instance array = arrayVal.getInstance();
+        private FieldValue getObfuscatedEnterpriseArrayLocation(Instance dynamicObject, Integer index, Instance actualLoc, Boolean allowInt) {
+            Instance array;
+            if (actualLoc != null) {
+                ObjectFieldValue arrayVal = (ObjectFieldValue) getValueImpl(actualLoc, dynamicObject);
+                array = arrayVal.getInstance();
+            } else {
+                array = getEnterpriseObjectStore(dynamicObject);
+            }
             if (array instanceof PrimitiveArrayInstance) {
                 PrimitiveArrayInstance arr = (PrimitiveArrayInstance) array;
                 if (allowInt != null) {
@@ -929,7 +976,29 @@ public class DynamicObject extends TruffleObject.InstanceBased {
             return null;
         }
 
-        private FieldValue getObfuscatedEnterpriseFieldLocation(Instance dynamicObject, Instance loc, Integer index, Instance type, Boolean allowInt) {
+        private FieldValue getObfuscatedEnterpriseFieldLocation(Instance dynamicObject, Instance loc, Integer index, Instance field_type, Boolean allowInt) {
+            Instance type = field_type;
+            if (isEterpriseFieldInfoObjSubClass(field_type)) {
+                String fieldName = null;
+                JavaClass fieldType = null;
+                for (FieldValue fv : field_type.getFieldValues()) {
+                    if (fv instanceof ObjectFieldValue) {
+                        Instance val = ((ObjectFieldValue)fv).getInstance();
+                        if (val == null) continue;
+                        String valName = val.getJavaClass().getName();
+                        if (valName.equals(String.class.getName())) {
+                            fieldName = DetailsSupport.getDetailsString(val);
+                        } else if ("tclass".equals(fv.getField().getName())) {
+                            type = val;
+                        } else if (valName.equals(Class.class.getName())) {
+                            fieldType = val.getJavaClass().getHeap().getJavaClassByID(val.getInstanceId());
+                        }
+                    }
+                }
+                assert type.getInstanceId() == dynamicObject.getJavaClass().getJavaClassId();
+                if (fieldName != null)
+                    return getDynamicObjectField(dynamicObject, fieldName, fieldType);
+            }
             if (type != null) { // TypedObjectFieldLocation
                 if (index.intValue() == 0) { // test for type Object[]
                     long typeClassId = type.getInstanceId();  // NOI18N
@@ -993,6 +1062,15 @@ public class DynamicObject extends TruffleObject.InstanceBased {
             return false;
         }
 
+        private FieldValue getDynamicObjectField(Instance dynamicObject, String fname, JavaClass fieldType) {
+             for (FieldValue fv : dynamicObject.getFieldValues()) {
+                 if (fv.getField().getName().equals(fname)) {
+                     return createFieldValue(dynamicObject, fv);
+                 }
+             }
+             throw new IllegalArgumentException(fname);
+        }
+
         private FieldValue getDynamicObjectPrimitiveField(Instance dynamicObject, int index) {
             return getDynamicObjectField(dynamicObject, index, false);
         }
