@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,14 +24,16 @@
  */
 package org.graalvm.visualvm.heapviewer.truffle.lang.r;
 
-import org.graalvm.visualvm.heapviewer.truffle.dynamicobject.DynamicObject;
-import org.graalvm.visualvm.heapviewer.truffle.TruffleFrame;
 import java.util.AbstractList;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import org.graalvm.visualvm.heapviewer.truffle.TruffleFrame;
+import org.graalvm.visualvm.heapviewer.truffle.TruffleObject;
+import org.graalvm.visualvm.heapviewer.truffle.dynamicobject.DynamicObject;
+import org.graalvm.visualvm.heapviewer.utils.HeapUtils;
 import org.graalvm.visualvm.lib.jfluid.heap.ArrayItemValue;
 import org.graalvm.visualvm.lib.jfluid.heap.Field;
 import org.graalvm.visualvm.lib.jfluid.heap.FieldValue;
@@ -44,9 +46,6 @@ import org.graalvm.visualvm.lib.jfluid.heap.Type;
 import org.graalvm.visualvm.lib.jfluid.heap.Value;
 import org.graalvm.visualvm.lib.profiler.heapwalk.details.api.DetailsSupport;
 import org.graalvm.visualvm.lib.profiler.heapwalk.details.spi.DetailsUtils;
-import org.graalvm.visualvm.heapviewer.truffle.TruffleObject;
-import org.graalvm.visualvm.heapviewer.utils.HeapUtils;
-import org.graalvm.visualvm.lib.jfluid.heap.Heap;
 
 /**
  *
@@ -98,7 +97,7 @@ class RObject extends TruffleObject.InstanceBased {
     private static Map<String,String> typeMap;
 
     static {
-        typeMap = new HashMap();
+        typeMap = new HashMap<>();
         for (int i=0; i<typeMaping.length; i+=2) {
             typeMap.put(typeMaping[i], typeMaping[i+1]);
         }
@@ -123,11 +122,11 @@ class RObject extends TruffleObject.InstanceBased {
     private String type;
 
 
-    public RObject(Instance instance) {
+    RObject(Instance instance) {
         this(null, instance);
     }
 
-    public RObject(String type, Instance instance) {
+    RObject(String type, Instance instance) {
         this.instance = instance;
         this.type = type;
 
@@ -185,13 +184,13 @@ class RObject extends TruffleObject.InstanceBased {
     }
     
     @Override
-    public String getType(Heap heap) {
+    public String getType() {
         if (type == null) type = getType(className);
         return type;
     }
 
     @Override
-    public long getTypeId(Heap heap) {
+    public long getTypeId() {
         return instance.getJavaClass().getJavaClassId();
     }
     
@@ -287,7 +286,7 @@ class RObject extends TruffleObject.InstanceBased {
                 for (Object name : namesArr) {
                     Instance string = (Instance) name;
 
-                    names.add(DetailsUtils.getInstanceString(string, null));
+                    names.add(DetailsUtils.getInstanceString(string));
                 }
                 return names;
             }
@@ -337,7 +336,7 @@ class RObject extends TruffleObject.InstanceBased {
 
     List<FieldValue> getReferences() {
         List<Value> refs = instance.getReferences();
-        List<FieldValue> robjRefs = new ArrayList();
+        List<FieldValue> robjRefs = new ArrayList<>();
 
         for (Value ref : refs) {
             Instance defInstance = ref.getDefiningInstance();
@@ -481,8 +480,7 @@ class RObject extends TruffleObject.InstanceBased {
     }
 
     static Instance findDataField(Instance instance) {
-        for (Object val : instance.getFieldValues()) {
-            FieldValue fv = (FieldValue) val;
+        for (FieldValue fv : instance.getFieldValues()) {
 
             if (fv instanceof ObjectFieldValue && "data".equals(fv.getField().getName())) { // NOI18N
                 Instance data = ((ObjectFieldValue)fv).getInstance();
@@ -517,7 +515,7 @@ class RObject extends TruffleObject.InstanceBased {
 
                 length = 0;
                 values = new ArrayList();
-                List<String> nameList = new ArrayList();
+                List<String> nameList = new ArrayList<>();
                 for (Instance cdr = pairListInstance;
                    cdr != null && cdr.getJavaClass().equals(pairListClass);
                    cdr = (Instance) cdr.getValueOfField("cdr")) { // NOI18N
@@ -634,7 +632,7 @@ class RObject extends TruffleObject.InstanceBased {
                 if (tag.getJavaClass().getName().equals(RNULL_FQN)) {
                     return null;
                 }
-                return DetailsSupport.getDetailsString(tag, null);
+                return DetailsSupport.getDetailsString(tag);
             }
             return null;
         }
@@ -703,7 +701,7 @@ class RObject extends TruffleObject.InstanceBased {
 
     private class RLogicalFieldValue extends RFieldValue {
 
-        public RLogicalFieldValue(int i) {
+        RLogicalFieldValue(int i) {
             super(i);
         }
 
@@ -728,7 +726,7 @@ class RObject extends TruffleObject.InstanceBased {
 
     private class RComplexFieldValue extends RFieldValue {
 
-        public RComplexFieldValue(int i) {
+        RComplexFieldValue(int i) {
             super(i);
         }
 
@@ -789,7 +787,7 @@ class RObject extends TruffleObject.InstanceBased {
         }
     }
     
-    private class FrameFieldValue implements ObjectFieldValue {
+    private static class FrameFieldValue implements ObjectFieldValue {
 
         final ObjectFieldValue frameValue;
         final Instance rObject;
@@ -878,12 +876,7 @@ class RObject extends TruffleObject.InstanceBased {
 
         @Override
         public Type getType() {
-            return new Type() {
-                @Override
-                public String getName() {
-                    return dataType;
-                }
-            };
+            return new RFieldType(dataType);
         }
     }
 
@@ -898,12 +891,34 @@ class RObject extends TruffleObject.InstanceBased {
 
         @Override
         public Type getType() {
-            return new Type() {
-                @Override
-                public String getName() {
-                    return name;
-                }
-            };
+            return new RFieldType(name);
+        }
+    }
+
+    private static class RFieldType implements Type {
+
+        private final String name;
+
+        RFieldType(String n) {
+            name = n;
+        }
+
+        @Override
+        public String getName() {
+            return name;
+        }
+
+        @Override
+        public boolean equals(Object obj) {
+            if (obj instanceof RFieldType) {
+                return getName().equals(((RFieldType)obj).getName());
+            }
+            return false;
+        }
+
+        @Override
+        public int hashCode() {
+            return getName().hashCode();
         }
     }
 }
