@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  * 
  * This code is free software; you can redistribute it and/or modify it
@@ -24,27 +24,6 @@
  */
 package org.graalvm.visualvm.heapviewer.truffle.ui;
 
-import org.graalvm.visualvm.heapviewer.truffle.swing.LinkButton;
-import org.graalvm.visualvm.heapviewer.truffle.swing.Splitter;
-import org.graalvm.visualvm.core.ui.components.SectionSeparator;
-import org.graalvm.visualvm.heapviewer.HeapContext;
-import org.graalvm.visualvm.heapviewer.model.DataType;
-import org.graalvm.visualvm.heapviewer.model.HeapViewerNode;
-import org.graalvm.visualvm.heapviewer.truffle.TruffleLanguage;
-import org.graalvm.visualvm.heapviewer.truffle.TruffleLanguageHeapFragment;
-import org.graalvm.visualvm.heapviewer.truffle.TruffleObject;
-import org.graalvm.visualvm.heapviewer.truffle.nodes.TruffleObjectNode;
-import org.graalvm.visualvm.heapviewer.truffle.TruffleObjectsProvider;
-import org.graalvm.visualvm.heapviewer.truffle.TruffleType;
-import org.graalvm.visualvm.heapviewer.truffle.nodes.TruffleTypeNode;
-import org.graalvm.visualvm.heapviewer.ui.HeapView;
-import org.graalvm.visualvm.heapviewer.ui.HeapViewerActions;
-import org.graalvm.visualvm.heapviewer.ui.HeapViewerFeature;
-import org.graalvm.visualvm.heapviewer.ui.HeapViewerNodeAction;
-import org.graalvm.visualvm.heapviewer.ui.SummaryView;
-import org.graalvm.visualvm.heapviewer.ui.TreeTableViewColumn;
-import org.graalvm.visualvm.uisupport.SeparatorLine;
-import org.graalvm.visualvm.uisupport.VerticalLayout;
 import java.awt.BorderLayout;
 import java.awt.Component;
 import java.awt.Container;
@@ -79,17 +58,38 @@ import javax.swing.SwingUtilities;
 import javax.swing.Timer;
 import javax.swing.table.DefaultTableModel;
 import javax.swing.table.TableModel;
+import org.graalvm.visualvm.core.ui.components.SectionSeparator;
+import org.graalvm.visualvm.heapviewer.HeapContext;
+import org.graalvm.visualvm.heapviewer.model.DataType;
+import org.graalvm.visualvm.heapviewer.model.HeapViewerNode;
+import org.graalvm.visualvm.heapviewer.truffle.TruffleLanguage;
+import org.graalvm.visualvm.heapviewer.truffle.TruffleLanguageHeapFragment;
+import org.graalvm.visualvm.heapviewer.truffle.TruffleObject;
+import org.graalvm.visualvm.heapviewer.truffle.TruffleObjectsProvider;
+import org.graalvm.visualvm.heapviewer.truffle.TruffleType;
+import org.graalvm.visualvm.heapviewer.truffle.nodes.TruffleObjectNode;
+import org.graalvm.visualvm.heapviewer.truffle.nodes.TruffleTypeNode;
+import org.graalvm.visualvm.heapviewer.truffle.swing.LinkButton;
+import org.graalvm.visualvm.heapviewer.truffle.swing.Splitter;
+import org.graalvm.visualvm.heapviewer.ui.HeapView;
+import org.graalvm.visualvm.heapviewer.ui.HeapViewerActions;
+import org.graalvm.visualvm.heapviewer.ui.HeapViewerFeature;
+import org.graalvm.visualvm.heapviewer.ui.HeapViewerNodeAction;
+import org.graalvm.visualvm.heapviewer.ui.SummaryView;
+import org.graalvm.visualvm.heapviewer.ui.TreeTableViewColumn;
 import org.graalvm.visualvm.lib.jfluid.heap.Heap;
 import org.graalvm.visualvm.lib.jfluid.heap.Instance;
+import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
+import org.graalvm.visualvm.lib.profiler.api.icons.LanguageIcons;
+import org.graalvm.visualvm.lib.profiler.heapwalk.ui.icons.HeapWalkerIcons;
 import org.graalvm.visualvm.lib.ui.UIUtils;
 import org.graalvm.visualvm.lib.ui.components.ProfilerToolbar;
 import org.graalvm.visualvm.lib.ui.swing.ProfilerTable;
 import org.graalvm.visualvm.lib.ui.swing.renderer.HideableBarRenderer;
 import org.graalvm.visualvm.lib.ui.swing.renderer.LabelRenderer;
 import org.graalvm.visualvm.lib.ui.swing.renderer.ProfilerRenderer;
-import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
-import org.graalvm.visualvm.lib.profiler.api.icons.LanguageIcons;
-import org.graalvm.visualvm.lib.profiler.heapwalk.ui.icons.HeapWalkerIcons;
+import org.graalvm.visualvm.uisupport.SeparatorLine;
+import org.graalvm.visualvm.uisupport.VerticalLayout;
 import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
 
@@ -484,7 +484,7 @@ public class TruffleSummaryView extends HeapViewerFeature {
             Object[][] instancesBySizeData = new Object[objectsBySizeArr.length][2];
             for (int i = 0; i < instancesBySizeData.length; i++) {
                 O object = (O)objectsBySizeArr[i];
-                instancesBySizeData[i][0] = language.createObjectNode(object, object.getType(heap));
+                instancesBySizeData[i][0] = language.createObjectNode(object, object.getType());
                 instancesBySizeData[i][1] = objectsBySizeArr[i].getSize();
             }
             configureSnippet(objectsBySize, instancesBySizeData);
@@ -739,7 +739,7 @@ public class TruffleSummaryView extends HeapViewerFeature {
             Object[][] dominatorsByRetainedSizeData = new Object[dominatorsByRetainedSizeArr.length][2];
             for (int i = 0; i < dominatorsByRetainedSizeData.length; i++) {
                 O object = (O)dominatorsByRetainedSizeArr[i];
-                dominatorsByRetainedSizeData[i][0] = language.createObjectNode(object, object.getType(heap));
+                dominatorsByRetainedSizeData[i][0] = language.createObjectNode(object, object.getType());
                 dominatorsByRetainedSizeData[i][1] = dominatorsByRetainedSizeArr[i].getRetainedSize();
             }
             configureSnippet(dominatorsByRetainedSize, dominatorsByRetainedSizeData);
@@ -757,7 +757,7 @@ public class TruffleSummaryView extends HeapViewerFeature {
             }
             
             Set<Instance> rootInstances = TruffleObjectsProvider.getDominatorRoots(searchInstances);
-            List<O> rootObjects = new ArrayList();
+            List<O> rootObjects = new ArrayList<>();
             for (Instance root : rootInstances) rootObjects.add(language.createObject(root));
             
             return rootObjects;
