@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -74,6 +74,7 @@ import org.graalvm.visualvm.lib.jfluid.heap.Type;
 import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
 import org.graalvm.visualvm.lib.profiler.api.icons.LanguageIcons;
 import org.graalvm.visualvm.lib.profiler.api.icons.ProfilerIcons;
+import org.graalvm.visualvm.lib.ui.swing.renderer.HideableBarRenderer;
 import org.graalvm.visualvm.lib.ui.swing.renderer.NormalBoldGrayRenderer;
 import org.openide.util.NbBundle;
 import org.openide.util.NbPreferences;
@@ -133,10 +134,11 @@ class JavaFieldsPlugin extends HeapViewPlugin {
         
         heap = context.getFragment().getHeap();
         
+        TreeTableViewColumn count;
         TreeTableViewColumn[] columns = new TreeTableViewColumn[] {
             new TreeTableViewColumn.Name(),
             new TreeTableViewColumn.LogicalValue(),
-            new TreeTableViewColumn.Count(heap, true, true),
+            count = new TreeTableViewColumn.Count(heap, true, true),
             new TreeTableViewColumn.OwnSize(heap, false, false),
             new TreeTableViewColumn.RetainedSize(heap, false, false),
             new TreeTableViewColumn.ObjectID()
@@ -153,9 +155,10 @@ class JavaFieldsPlugin extends HeapViewPlugin {
                     
                     InstancesWrapper wrapper = HeapViewerNode.getValue(_selected, DataType.INSTANCES_WRAPPER, heap);
                     if (wrapper != null) {
-                        List<HeapViewerNode> fieldNodes = new ArrayList();
+                        List<HeapViewerNode> fieldNodes = new ArrayList<>();
                         
                         if (cFieldsHisto) {
+                            ((HideableBarRenderer)count.getRenderer()).setMaxValue(wrapper.getInstancesCount());
                             HeapViewerNode[] histo = getClassFieldsHistogram(wrapper, root, heap, viewID, viewFilter, dataTypes, sortOrders, progress);
                             fieldNodes.addAll(Arrays.asList(histo));
                         } else {
@@ -185,7 +188,7 @@ class JavaFieldsPlugin extends HeapViewPlugin {
                     } else {
                         Instance instance = HeapViewerNode.getValue(_selected, DataType.INSTANCE, heap);
                         if (instance != null) {
-                            List<FieldValue> fields = new ArrayList();
+                            List<FieldValue> fields = new ArrayList<>();
 
                             if (iFields) fields.addAll(instance.getFieldValues());
                             else filtered = true;
@@ -303,7 +306,7 @@ class JavaFieldsPlugin extends HeapViewPlugin {
                 return new FieldHistogramNode(field) {
                     @Override
                     InterruptibleIterator<Instance> instancesIterator() {
-                        return new InterruptibleIterator(instances.getInstancesIterator());
+                        return new InterruptibleIterator<>(instances.getInstancesIterator());
                     }
                     @Override
                     int instancesCount() {
@@ -313,7 +316,7 @@ class JavaFieldsPlugin extends HeapViewPlugin {
             }
             protected ProgressIterator<Field> objectsIterator(int index, Progress progress) {
                 Iterator<Field> iterator = fields.listIterator(index);
-                return new ProgressIterator(iterator, index, false, progress);
+                return new ProgressIterator<>(iterator, index, false, progress);
             }
             protected String getMoreNodesString(String moreNodesCount)  {
                 return Bundle.JavaFieldsPlugin_FieldsContainerMoreNodes(moreNodesCount);
@@ -403,7 +406,7 @@ class JavaFieldsPlugin extends HeapViewPlugin {
                         }
                         protected ProgressIterator<InstanceCounter.Record> objectsIterator(int index, Progress progress) {
                             Iterator<InstanceCounter.Record> iterator = values.iterator();
-                            return new ProgressIterator(iterator, index, true, progress);
+                            return new ProgressIterator<>(iterator, index, true, progress);
                         }
                         protected String getMoreNodesString(String moreNodesCount)  {
                             return Bundle.JavaFieldsPlugin_FieldHistogramMoreNodes(moreNodesCount);
@@ -562,7 +565,7 @@ class JavaFieldsPlugin extends HeapViewPlugin {
                             return value == null || !fieldValue.equals(value.getValue());
                         }
                     };
-                    return new ProgressIterator(fieldInstanceIterator, index, true, _progress);
+                    return new ProgressIterator<>(fieldInstanceIterator, index, true, _progress);
                 }
                 protected String getMoreNodesString(String moreNodesCount)  {
                     return Bundle.JavaFieldsPlugin_FieldHistogramMoreNodes(moreNodesCount);
@@ -651,7 +654,7 @@ class JavaFieldsPlugin extends HeapViewPlugin {
                             return !Objects.equals(_instance, ((ObjectFieldValue)value).getInstance());
                         }
                     };
-                    return new ProgressIterator(fieldInstanceIterator, index, true, _progress);
+                    return new ProgressIterator<>(fieldInstanceIterator, index, true, _progress);
                 }
                 protected String getMoreNodesString(String moreNodesCount)  {
                     return Bundle.JavaFieldsPlugin_FieldHistogramMoreNodes(moreNodesCount);
@@ -673,7 +676,7 @@ class JavaFieldsPlugin extends HeapViewPlugin {
     
     // TODO: make JavaClass.getAllInstanceFields() public?
     private static List<Field> getAllInstanceFields(JavaClass jclass) {
-        List<Field> fields = new ArrayList(50);
+        List<Field> fields = new ArrayList<>(50);
 
         for (JavaClass jcls = jclass; jcls != null; jcls = jcls.getSuperClass()) {
             fields.addAll(jcls.getFields());
