@@ -79,6 +79,7 @@ import org.graalvm.visualvm.lib.jfluid.heap.Value;
 import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
 import org.graalvm.visualvm.lib.profiler.api.icons.ProfilerIcons;
 import org.graalvm.visualvm.lib.ui.UIUtils;
+import org.graalvm.visualvm.lib.ui.swing.renderer.HideableBarRenderer;
 import org.graalvm.visualvm.lib.ui.swing.renderer.LabelRenderer;
 import org.openide.util.Lookup;
 import org.openide.util.NbBundle;
@@ -125,10 +126,11 @@ class JavaReferencesPlugin extends HeapViewPlugin {
         
         heap = context.getFragment().getHeap();
         
+        TreeTableViewColumn count;
         TreeTableViewColumn[] columns = new TreeTableViewColumn[] {
             new TreeTableViewColumn.Name(),
             new TreeTableViewColumn.LogicalValue(),
-            new TreeTableViewColumn.Count(heap, true, true),
+            count = new TreeTableViewColumn.Count(heap, true, true),
             new TreeTableViewColumn.OwnSize(heap, false, false),
             new TreeTableViewColumn.RetainedSize(heap, false, false),
             new TreeTableViewColumn.ObjectID()
@@ -166,6 +168,7 @@ class JavaReferencesPlugin extends HeapViewPlugin {
 
 //                    if (!mergedReferences) return new HeapViewerNode[] { new TextNode(Bundle.JavaReferencesPlugin_NoReferencesFiltered()) };
                     
+                    ((HideableBarRenderer)count.getRenderer()).setMaxValue(wrapper.getInstancesCount());
                     return computeInstancesReferences(wrapper, root, heap, viewID, null, dataTypes, sortOrders, progress);
                 } else {
                     SwingUtilities.invokeLater(new Runnable() {
@@ -313,13 +316,13 @@ class JavaReferencesPlugin extends HeapViewPlugin {
     
     
     private static InterruptibleIterator<Instance> instancesIterator(InstancesWrapper instances) {
-        return new InterruptibleIterator(instances.getInstancesIterator());
+        return new InterruptibleIterator<>(instances.getInstancesIterator());
     }
     
     private HeapViewerNode[] computeInstancesReferences(final InstancesWrapper instances, RootNode root, Heap heap, String viewID, HeapViewerNodeFilter viewFilter, List<DataType> dataTypes, List<SortOrder> sortOrders, Progress progress) throws InterruptedException {
         HeapOperations.initializeReferences(heap);
         
-        final Map<Long, Integer> values = new HashMap();
+        final Map<Long, Integer> values = new HashMap<>();
         
         try {        
             progress.setupKnownSteps(instances.getInstancesCount());
@@ -329,7 +332,7 @@ class JavaReferencesPlugin extends HeapViewPlugin {
                 Instance instance = instancesI.next();
                 progress.step();
                 List<Value> references = instance.getReferences();
-                Set<Instance> referers = new HashSet();
+                Set<Instance> referers = new HashSet<>();
                 if (references.isEmpty()) {
                     referers.add(null);
                 } else for (Value reference : references) {
@@ -368,7 +371,7 @@ class JavaReferencesPlugin extends HeapViewPlugin {
             }
             protected ProgressIterator<Map.Entry<Long, Integer>> objectsIterator(int index, Progress progress) {
                 Iterator<Map.Entry<Long, Integer>> iterator = values.entrySet().iterator();
-                return new ProgressIterator(iterator, index, true, progress);
+                return new ProgressIterator<>(iterator, index, true, progress);
             }
             protected String getMoreNodesString(String moreNodesCount)  {
                 return Bundle.JavaReferencesPlugin_MoreNodes(moreNodesCount);
@@ -463,7 +466,7 @@ class JavaReferencesPlugin extends HeapViewPlugin {
                             return true;
                         }
                     };
-                    return new ProgressIterator(fieldInstanceIterator, index, true, _progress);
+                    return new ProgressIterator<>(fieldInstanceIterator, index, true, _progress);
                 }
                 protected String getMoreNodesString(String moreNodesCount)  {
                     return Bundle.JavaReferencesPlugin_IMoreNodes(moreNodesCount);
@@ -554,7 +557,7 @@ class JavaReferencesPlugin extends HeapViewPlugin {
                 }
                 protected ProgressIterator<Value> objectsIterator(int index, Progress progress) {
                     Iterator<Value> iterator = references.listIterator(index);
-                    return new ProgressIterator(iterator, index, false, progress);
+                    return new ProgressIterator<>(iterator, index, false, progress);
                 }
                 protected String getMoreNodesString(String moreNodesCount)  {
                     return Bundle.JavaReferencesPlugin_MoreNodes(moreNodesCount);
@@ -577,7 +580,7 @@ class JavaReferencesPlugin extends HeapViewPlugin {
     }
     
     
-    private static final Set<String> COLLAPSED_ITEMS = new HashSet(Arrays.asList(new String[] {
+    private static final Set<String> COLLAPSED_ITEMS = new HashSet<>(Arrays.asList(new String[] {
         "java.util.HashMap$Node", // NOI18N
         "java.util.WeakHashMap$Entry" // NOI18N
     }));
