@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -82,6 +82,7 @@ import org.graalvm.visualvm.lib.jfluid.heap.Value;
 import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
 import org.graalvm.visualvm.lib.profiler.api.icons.ProfilerIcons;
 import org.graalvm.visualvm.lib.ui.UIUtils;
+import org.graalvm.visualvm.lib.ui.swing.renderer.HideableBarRenderer;
 import org.graalvm.visualvm.lib.ui.swing.renderer.LabelRenderer;
 import org.graalvm.visualvm.lib.ui.swing.renderer.MultiRenderer;
 import org.graalvm.visualvm.lib.ui.swing.renderer.NormalBoldGrayRenderer;
@@ -128,10 +129,11 @@ public class PathToGCRootPlugin extends HeapViewPlugin {
         
         heap = context.getFragment().getHeap();
         
+        TreeTableViewColumn count;
         TreeTableViewColumn[] columns = new TreeTableViewColumn[] {
             new TreeTableViewColumn.Name(),
             new TreeTableViewColumn.LogicalValue(),
-            new TreeTableViewColumn.Count(heap, true, true),
+            count = new TreeTableViewColumn.Count(heap, true, true),
             new TreeTableViewColumn.OwnSize(heap, false, false),
             new TreeTableViewColumn.RetainedSize(heap, false, false),
             new TreeTableViewColumn.ObjectID()
@@ -191,6 +193,7 @@ public class PathToGCRootPlugin extends HeapViewPlugin {
                     data = computeInstanceRoots(instance, progress);
                     if (data != null) showingClass = false;
                 } else {
+                    ((HideableBarRenderer)count.getRenderer()).setMaxValue(wrapper.getInstancesCount());
                     data = computeInstancesRoots(wrapper.getInstancesIterator(), wrapper.getInstancesCount(), progress);
                     if (data != null) showingClass = true;
                 }
@@ -207,8 +210,8 @@ public class PathToGCRootPlugin extends HeapViewPlugin {
                         return node;
                     }
                     protected ProgressIterator<HeapViewerNode> objectsIterator(int index, Progress progress) {
-                        Iterator iterator = _data.iterator();
-                        return new ProgressIterator(iterator, index, true, progress);
+                        Iterator<HeapViewerNode> iterator = _data.iterator();
+                        return new ProgressIterator<>(iterator, index, true, progress);
                     }
                     protected String getMoreNodesString(String moreNodesCount)  {
                         return Bundle.PathToGCRootPlugin_MoreNodes(moreNodesCount);
@@ -420,7 +423,7 @@ public class PathToGCRootPlugin extends HeapViewPlugin {
     }
     
     private static Collection<HeapViewerNode> computeInstancesRoots(Iterator<Instance> instances, int count, Progress progress) throws InterruptedException {
-        Map<Instance, HeapViewerNode> gcRoots = new HashMap();
+        Map<Instance, HeapViewerNode> gcRoots = new HashMap<>();
         Map<Instance,Instance> gcRootCache = new HashMap<>();
         
         try {
@@ -493,7 +496,7 @@ public class PathToGCRootPlugin extends HeapViewPlugin {
         
 //        private final int maxNodes = UIThresholds.MAX_MERGED_OBJECTS;
         
-        private final List<Instance> instances = new ArrayList();
+        private final List<Instance> instances = new ArrayList<>();
         
         
         GCRootNode(Instance gcRoot) {
@@ -537,7 +540,7 @@ public class PathToGCRootPlugin extends HeapViewPlugin {
                 }
                 protected ProgressIterator<Instance> objectsIterator(int index, Progress progress) {
                     Iterator<Instance> iterator = instances.listIterator(index);
-                    return new ProgressIterator(iterator, index, false, progress);
+                    return new ProgressIterator<>(iterator, index, false, progress);
                 }
                 protected String getMoreNodesString(String moreNodesCount)  {
                     return Bundle.GCRootNode_MoreNodes(moreNodesCount);
