@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -151,7 +151,7 @@ import org.openide.windows.TopComponent;
 })
 public class OQLConsoleView extends HeapViewerFeature {
     
-    private static final int RESULTS_LIMIT = Integer.parseInt(System.getProperty("OQLController.limitResults", "100")); // NOI18N
+    private static final int RESULTS_LIMIT = Integer.getInteger("OQLController.limitResults", 100); // NOI18N
     
     
     private static final String GRAALJS_CODENAMEBASE = "org.graalvm.visualvm.modules.graaljs"; // NOI18N
@@ -589,7 +589,7 @@ public class OQLConsoleView extends HeapViewerFeature {
                             htmlToolbar.add(new GrayLabel(Bundle.OQLConsoleView_ResultsLimit()));
                             htmlToolbar.addSpace(3);
                             
-                            Set<Integer> limits = new TreeSet();
+                            Set<Integer> limits = new TreeSet<>();
                             limits.add(10);
                             limits.add(100);
                             limits.add(1000);
