@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2019, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,6 +25,8 @@
 
 package org.graalvm.visualvm.jfr;
 
+import org.graalvm.visualvm.jfr.model.impl.JfrModelProvider;
+import org.graalvm.visualvm.tools.jfr.JfrModelFactory;
 import org.openide.modules.ModuleInstall;
 
 
@@ -36,6 +38,7 @@ final class Installer extends ModuleInstall {
     
     public void restored() {
         JFRSnapshotSupport.register();
+        JfrModelFactory.getDefault().registerProvider(new JfrModelProvider());
     }
     
 }
