@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2019, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -97,7 +97,7 @@ class MonitorViewSupport {
                 add(MessageComponent.notAvailable(), BorderLayout.CENTER);
             } else if (!model.containsEvent(JFRSnapshotMonitorViewProvider.EventChecker.class)) {
                 // Remove the Java 7 only event from the list of required events (http://www.oracle.com/hotspot/jvm/vm/gc/heap/perm_gen_summary)
-                List<String> eventTypes = new ArrayList();
+                List<String> eventTypes = new ArrayList<>();
                 eventTypes.addAll(Arrays.asList(JFRSnapshotMonitorViewProvider.EventChecker.checkedTypes()));
                 eventTypes.remove(JFRSnapshotMonitorViewProvider.EVENT_PERMGEN_SUMMARY);
                 
@@ -208,7 +208,7 @@ class MonitorViewSupport {
         
         @Override
         public void init() {
-            records = new ArrayList();
+            records = new ArrayList<>();
         }
         
         @Override
@@ -292,7 +292,7 @@ class MonitorViewSupport {
 
         private SimpleXYChartSupport chartSupport;
 
-        public HeapViewSupport(JFRModel jfrModel) {
+        HeapViewSupport(JFRModel jfrModel) {
             this.jfrModel = jfrModel;
             initModels();
             initComponents();
@@ -321,7 +321,7 @@ class MonitorViewSupport {
         
         @Override
         public void init() {
-            records = new ArrayList();
+            records = new ArrayList<>();
         }
         
         @Override
@@ -422,7 +422,7 @@ class MonitorViewSupport {
 
         private SimpleXYChartSupport chartSupport;
 
-        public PermGenViewSupport(JFRModel jfrModel) {
+        PermGenViewSupport(JFRModel jfrModel) {
             this.jfrModel = jfrModel;
             initModels();
             initComponents();
@@ -451,7 +451,7 @@ class MonitorViewSupport {
         
         @Override
         public void init() {
-            records = new ArrayList();
+            records = new ArrayList<>();
         }
         
         @Override
@@ -553,7 +553,7 @@ class MonitorViewSupport {
 
         private SimpleXYChartSupport chartSupport;
 
-        public MetaspaceViewSupport(JFRModel jfrModel) {
+        MetaspaceViewSupport(JFRModel jfrModel) {
             this.jfrModel = jfrModel;
             initModels();
             initComponents();
@@ -582,7 +582,7 @@ class MonitorViewSupport {
         
         @Override
         public void init() {
-            records = new ArrayList();
+            records = new ArrayList<>();
         }
         
         @Override
@@ -717,7 +717,7 @@ class MonitorViewSupport {
         
         @Override
         public void init() {
-            records = new ArrayList();
+            records = new ArrayList<>();
         }
         
         @Override
@@ -849,7 +849,7 @@ class MonitorViewSupport {
         
         @Override
         public void init() {
-            records = new ArrayList();
+            records = new ArrayList<>();
         }
         
         @Override
