@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2019, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -35,7 +35,6 @@ import java.util.Collections;
 import java.util.Comparator;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -278,9 +277,9 @@ class ThreadsViewSupport {
         
         @Override
         public void init() {
-            states = new HashMap();
-            definitions = new TreeMap();
-            ignoredEvents = new HashSet();
+            states = new HashMap<>();
+            definitions = new TreeMap<>();
+            ignoredEvents = new HashSet<>();
         }
         
         @Override
@@ -347,18 +346,14 @@ class ThreadsViewSupport {
         
         @Override
         public void done() {
-            final Collection<ThreadData> tdataC = new ArrayList();
+            final Collection<ThreadData> tdataC = new ArrayList<>();
             
-            Iterator<Map.Entry<Long, Definition>> definitionsI = definitions.entrySet().iterator();
-            
-            while (definitionsI.hasNext()) {
-                Map.Entry<Long, Definition> definitionE = definitionsI.next();
-                
+            for (Map.Entry<Long, Definition> definitionE : definitions.entrySet()) {
                 long tid = definitionE.getKey();
                 Definition definition = definitionE.getValue();
                 
                 List<State> statesL = states.get(tid);
-                if (statesL == null) statesL = new ArrayList();
+                if (statesL == null) statesL = new ArrayList<>();
                 Collections.sort(statesL, State.COMPARATOR);
                 
                 if (statesL.isEmpty() && definition.firstState != Byte.MIN_VALUE) {
@@ -401,7 +396,7 @@ class ThreadsViewSupport {
         
         
         Collection<String> getActiveTypes() {
-            List<String> names = new ArrayList();
+            List<String> names = new ArrayList<>();
             
             if (activeTypes[0]) names.add("jdk.ThreadStart"); // NOI18N
             if (activeTypes[1]) names.add("jdk.ThreadEnd"); // NOI18N
@@ -429,7 +424,7 @@ class ThreadsViewSupport {
                 List<State> tdata = states.get(tid);
                 
                 if (tdata == null) {
-                    tdata = new ArrayList();
+                    tdata = new ArrayList<>();
                     states.put(tid, tdata);
                 }
                 
