@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
+ *  Copyright (c) 2007, 2023, Oracle and/or its affiliates. All rights reserved.
  *  DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  * 
  *  This code is free software; you can redistribute it and/or modify it
@@ -25,14 +25,13 @@
 
 package org.graalvm.visualvm.jmx;
 
+import java.io.File;
+import javax.swing.SwingUtilities;
 import org.graalvm.visualvm.application.Application;
 import org.graalvm.visualvm.core.datasource.Storage;
 import org.graalvm.visualvm.core.datasupport.Utils;
 import org.graalvm.visualvm.jmx.impl.JmxApplicationProvider;
-import java.io.File;
-import javax.swing.SwingUtilities;
 import org.netbeans.api.progress.ProgressHandle;
-import org.netbeans.api.progress.ProgressHandleFactory;
 import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
 import org.openide.util.NbBundle;
@@ -230,7 +229,7 @@ public final class JmxApplicationsSupport {
                     displayName, connectionString, username);
             SwingUtilities.invokeLater(new Runnable() {
                     public void run() {
-                        pHandle[0] = ProgressHandleFactory.createHandle(
+                        pHandle[0] = ProgressHandle.createHandle(
                                 NbBundle.getMessage(JmxApplicationsSupport.class,
                                                     "LBL_Adding", suggestedName)); // NOI18N
                         pHandle[0].setInitialDelay(0);
@@ -334,7 +333,7 @@ public final class JmxApplicationsSupport {
                     displayName, connectionString, username);
             SwingUtilities.invokeLater(new Runnable() {
                     public void run() {
-                        pHandle[0] = ProgressHandleFactory.createHandle(
+                        pHandle[0] = ProgressHandle.createHandle(
                                 NbBundle.getMessage(JmxApplicationsSupport.class,
                                                     "LBL_Adding", suggestedName)); // NOI18N
                         pHandle[0].setInitialDelay(0);
@@ -371,8 +370,8 @@ public final class JmxApplicationsSupport {
     }
     
     private static String getUsername(EnvironmentProvider provider) {
-        return provider instanceof CredentialsProvider ?
-                ((CredentialsProvider)provider).getUsername(null) : null;
+        return provider instanceof CredentialsProvider.Custom ?
+                ((CredentialsProvider.Custom)provider).getUsername(null) : null;
     }
     
     static String getStorageDirectoryString() {
