@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -30,6 +30,7 @@ import javax.management.MBeanServerConnection;
 import javax.management.remote.JMXServiceURL;
 import org.graalvm.visualvm.application.jvm.HeapHistogram;
 import org.graalvm.visualvm.tools.jmx.JmxModel;
+import org.graalvm.visualvm.tools.jmx.JvmMXBeans;
 
 /**
  *
@@ -53,6 +54,11 @@ class DisconnectedJmxModel extends JmxModel {
         return null;
     }
 
+    @Override
+    public JvmMXBeans getJvmMXBeans() {
+        return null;
+    }
+
     @Override
     public JMXServiceURL getJMXServiceURL() {
         return url;
