@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -29,8 +29,36 @@ import com.sun.tools.attach.AgentInitializationException;
 import com.sun.tools.attach.AgentLoadException;
 import com.sun.tools.attach.AttachNotSupportedException;
 import com.sun.tools.attach.VirtualMachine;
+import java.awt.EventQueue;
+import java.beans.PropertyChangeEvent;
+import java.beans.PropertyChangeListener;
+import java.io.ByteArrayOutputStream;
+import java.io.File;
+import java.io.IOException;
+import java.io.PrintWriter;
+import java.lang.reflect.InvocationHandler;
+import java.lang.reflect.InvocationTargetException;
+import java.lang.reflect.Method;
+import java.lang.reflect.Proxy;
+import java.util.List;
+import java.util.Map;
+import java.util.Properties;
+import java.util.StringTokenizer;
+import java.util.concurrent.Callable;
+import java.util.concurrent.ExecutionException;
+import java.util.concurrent.ExecutorService;
+import java.util.concurrent.Executors;
+import java.util.concurrent.Future;
+import java.util.concurrent.TimeUnit;
+import java.util.concurrent.TimeoutException;
+import java.util.logging.Level;
+import java.util.logging.Logger;
+import javax.management.MBeanServerConnection;
+import javax.management.remote.JMXServiceURL;
+import javax.swing.SwingUtilities;
 import org.graalvm.visualvm.application.Application;
 import org.graalvm.visualvm.application.jvm.HeapHistogram;
+import org.graalvm.visualvm.core.VisualVM;
 import org.graalvm.visualvm.core.datasupport.DataRemovedListener;
 import org.graalvm.visualvm.core.datasupport.Stateful;
 import org.graalvm.visualvm.tools.attach.AttachModelFactory;
@@ -38,30 +66,12 @@ import org.graalvm.visualvm.tools.jmx.CachedMBeanServerConnection;
 import org.graalvm.visualvm.tools.jmx.CachedMBeanServerConnectionFactory;
 import org.graalvm.visualvm.tools.jmx.JmxModel;
 import org.graalvm.visualvm.tools.jmx.JmxModelFactory;
+import org.graalvm.visualvm.tools.jmx.JvmMXBeans;
+import org.graalvm.visualvm.tools.jmx.JvmMXBeansFactory;
 import org.graalvm.visualvm.tools.jvmstat.JvmJvmstatModel;
 import org.graalvm.visualvm.tools.jvmstat.JvmJvmstatModelFactory;
 import org.graalvm.visualvm.tools.jvmstat.JvmstatModel;
-import java.awt.EventQueue;
-import java.beans.PropertyChangeEvent;
-import java.beans.PropertyChangeListener;
-import java.io.ByteArrayOutputStream;
-import java.io.File;
-import java.io.IOException;
-import java.io.InputStream;
-import java.io.PrintWriter;
-import java.lang.reflect.InvocationHandler;
-import java.lang.reflect.InvocationTargetException;
-import java.lang.reflect.Method;
-import java.lang.reflect.Proxy;
-import java.util.List;
-import java.util.Properties;
-import java.util.StringTokenizer;
-import java.util.logging.Level;
-import java.util.logging.Logger;
-import javax.management.MBeanServerConnection;
-import javax.management.remote.JMXServiceURL;
-import org.graalvm.visualvm.core.VisualVM;
-import sun.tools.attach.HotSpotVirtualMachine;
+import org.openide.util.Utilities;
 
 /**
  * This class encapsulates the JMX functionality of the target Java application.
@@ -105,13 +115,15 @@ class JmxModelImpl extends JmxModel {
     private ApplicationAvailabilityListener availabilityListener;
     private JmxSupport jmxSupport;
     private final Object jmxSupportLock = new Object();
+    private JvmMXBeans mxbeans;
+    private final Object mxbeansLock = new Object();
     
     /**
      * Creates an instance of {@code JmxModel} for a {@link JvmstatApplication}.
      *
      * @param application the {@link JvmstatApplication}.
      */
-    public JmxModelImpl(Application application, JvmstatModel jvmstat) {
+    JmxModelImpl(Application application, JvmstatModel jvmstat) {
         try {
             JvmJvmstatModel jvmstatModel = JvmJvmstatModelFactory.getJvmstatModelFor(application);
             // Create ProxyClient (i.e. create the JMX connection to the JMX agent)
@@ -143,7 +155,7 @@ class JmxModelImpl extends JmxModel {
                 // JMX management agent using the port and security
                 // related information retrieved through jvmstat.
                 List<String> urls = jvmstat.findByPattern("sun.management.JMXConnectorServer.[0-9]+.remoteAddress"); // NOI18N
-                if (urls.size() != 0) {
+                if (!urls.isEmpty()) {
                     List<String> auths = jvmstat.findByPattern("sun.management.JMXConnectorServer.[0-9]+.authenticate"); // NOI18N
                     proxyClient = new ProxyClient(application, urls.get(0));
                     if ("true".equals(auths.get(0))) {  // NOI18N
@@ -161,7 +173,7 @@ class JmxModelImpl extends JmxModel {
                     while (st.hasMoreTokens()) {
                         String token = st.nextToken();
                         if (token.startsWith("-Dcom.sun.management.jmxremote.port=")) { // NOI18N
-                            port = Integer.parseInt(token.substring(token.indexOf("=") + 1)); // NOI18N
+                            port = Integer.parseInt(token.substring(token.indexOf('=') + 1)); // NOI18N
                         } else if (token.equals("-Dcom.sun.management.jmxremote.authenticate=true")) { // NOI18N
                             authenticate = true;
                         }
@@ -204,7 +216,7 @@ class JmxModelImpl extends JmxModel {
      *
      * @param application the {@link JmxApplication}.
      */
-    public JmxModelImpl(JmxApplication application) {
+    JmxModelImpl(JmxApplication application) {
         try {
             client = application.getProxyClient();
             removedListener = new ApplicationRemovedListener();
@@ -260,6 +272,24 @@ class JmxModelImpl extends JmxModel {
         return null;
     }
 
+    /**
+     * <p>Method for obtaining the {@link JvmMXBeans} for
+     * the given {@link JmxModel}.</p>
+     *
+     * @return a {@link JvmMXBeans} instance containing the MXBean
+     * proxies for the Java platform MXBeans backed by the supplied
+     * {@link JmxModel}. No MBean caching is applied on the supplied
+     * {@link JmxModel}.
+     */
+    public JvmMXBeans getJvmMXBeans() {
+        synchronized (mxbeansLock) {
+            if (mxbeans == null) {
+                mxbeans = JvmMXBeansFactory.getJvmMXBeans(this);
+            }
+            return mxbeans;
+        }
+    }
+
     /**
      * Returns the {@link JMXServiceURL} associated to this (@code JmxModel}.
      *
@@ -310,6 +340,14 @@ class JmxModelImpl extends JmxModel {
         return support.getThreadBean() != null && !support.isReadOnlyConnection();
     }
 
+    public String executeJCmd(String command, Map<String,Object> pars) {
+        JmxSupport support = getJmxSupport();
+        if (support.isReadOnlyConnection()) {
+            return null;
+        }
+        return support.executeJCmd(command, pars);
+    }
+
     public String getCommandLine() {
         JmxSupport support = getJmxSupport();
         if (support.isReadOnlyConnection()) {
@@ -359,12 +397,12 @@ class JmxModelImpl extends JmxModel {
         private Checker() {
         }
 
-        public static MBeanServerConnection newChecker(
+        static MBeanServerConnection newChecker(
                 ProxyClient client, MBeanServerConnection mbsc) {
             final InvocationHandler ih = new CheckerInvocationHandler(mbsc);
             return (MBeanServerConnection) Proxy.newProxyInstance(
                     Checker.class.getClassLoader(),
-                    new Class[]{MBeanServerConnection.class},
+                    new Class<?>[]{MBeanServerConnection.class},
                     ih);
         }
     }
@@ -407,9 +445,8 @@ class JmxModelImpl extends JmxModel {
     }
 
     static class LocalVirtualMachine {
+        private static ExecutorService winExec = Executors.newCachedThreadPool();
 
-        private static final String ENABLE_LOCAL_AGENT_JCMD = "ManagementAgent.start_local";  // NOI18N
-        
         private int vmid;
         private boolean isAttachSupported;
         private String javaHome;
@@ -417,26 +454,26 @@ class JmxModelImpl extends JmxModel {
         // @GuardedBy this
         volatile private String address;
 
-        public LocalVirtualMachine(int vmid, boolean canAttach, String connectorAddress, String home) {
+        LocalVirtualMachine(int vmid, boolean canAttach, String connectorAddress, String home) {
             this.vmid = vmid;
             this.address = connectorAddress;
             this.isAttachSupported = canAttach;
             this.javaHome = home;
         }
 
-        public int vmid() {
+        int vmid() {
             return vmid;
         }
 
-        public synchronized boolean isManageable() {
+        synchronized boolean isManageable() {
             return (address != null);
         }
 
-        public boolean isAttachable() {
+        boolean isAttachable() {
             return isAttachSupported;
         }
 
-        public synchronized void startManagementAgent() throws IOException {
+        synchronized void startManagementAgent() throws IOException {
             if (address != null) {
                 // already started
                 return;
@@ -446,8 +483,15 @@ class JmxModelImpl extends JmxModel {
                 throw new IOException("This virtual machine \"" + vmid +    // NOI18N
                         "\" does not support dynamic attach."); // NOI18N
             }
-
-            loadManagementAgent();
+            executeAndWait(() -> {
+                try {
+                    loadManagementAgent();
+                } catch (IOException ex) {
+                    LOGGER.log(Level.INFO, "loadManagementAgent for PID "+vmid+" failed", ex); // NOI18N
+                }
+                // rerurn void
+                return null;
+            });
             // fails to load or start the management agent
             if (address == null) {
                 // should never reach here
@@ -455,14 +499,15 @@ class JmxModelImpl extends JmxModel {
             }
         }
 
-        public synchronized String connectorAddress() {
+        synchronized String connectorAddress() {
             // return null if not available or no JMX agent
             return address;
         }
+
         private static final String LOCAL_CONNECTOR_ADDRESS_PROP =
                 "com.sun.management.jmxremote.localConnectorAddress";   // NOI18N
 
-        private synchronized void loadManagementAgent() throws IOException {
+        private void loadManagementAgent() throws IOException {
             VirtualMachine vm = null;
             String name = String.valueOf(vmid);
             try {
@@ -471,15 +516,15 @@ class JmxModelImpl extends JmxModel {
                 throw new IOException(x);
             }
             // try to enable local JMX via jcmd command
-            if (!loadManagementAgentViaJcmd(vm)) {
+            address = loadManagementAgentViaJcmd(vm);
+            if (address == null) {
                 // load the management agent into the target VM
                 loadManagementAgentViaJar(vm);
+                // get the connector address
+                Properties agentProps = vm.getAgentProperties();
+                address = (String) agentProps.get(LOCAL_CONNECTOR_ADDRESS_PROP);
             }
 
-            // get the connector address
-            Properties agentProps = vm.getAgentProperties();
-            address = (String) agentProps.get(LOCAL_CONNECTOR_ADDRESS_PROP);
-
             vm.detach();
         }
 
@@ -509,32 +554,31 @@ class JmxModelImpl extends JmxModel {
             }
         }
 
-        private boolean loadManagementAgentViaJcmd(VirtualMachine vm) throws IOException {
-            if (vm instanceof HotSpotVirtualMachine) {
-                HotSpotVirtualMachine hsvm = (HotSpotVirtualMachine) vm;
-                InputStream in = null;
+        private String loadManagementAgentViaJcmd(VirtualMachine vm) {
+            try {
+                return vm.startLocalManagementAgent();
+            } catch (IOException ex) {
+                LOGGER.log(Level.INFO, "startLocalManagementAgent for PID "+vmid+" failed", ex); // NOI18N
+            }
+            return null;
+        }
+
+        // see AttachModelImpl.executeAndWait
+        private static <V> V executeAndWait(Callable<V> call) {
+            if (Utilities.isWindows()) {
+                Future<V> result = winExec.submit(call);
                 try {
-                    byte b[] = new byte[256];
-                    int n;
-                    
-                    in = hsvm.executeJCmd(ENABLE_LOCAL_AGENT_JCMD);
-                    do {
-                        n = in.read(b);
-                        if (n > 0) {
-                            String s = new String(b, 0, n, "UTF-8");    // NOI18N
-                            System.out.print(s);
-                        }
-                    } while (n > 0);
-                    return true;
-                } catch (IOException ex) {
-                    LOGGER.log(Level.INFO, "jcmd command \""+ENABLE_LOCAL_AGENT_JCMD+"\" for PID "+vmid+" failed", ex); // NOI18N
-                } finally {
-                    if (in != null) {
-                        in.close();
-                    }
+                    return result.get(SwingUtilities.isEventDispatchThread() ? 5 : 25, TimeUnit.SECONDS);
+                } catch (InterruptedException | ExecutionException | TimeoutException ex) {
+                    LOGGER.log(Level.INFO, "executeAndWait get", ex);    // NOI18N
                 }
+                return null;
+            }
+            try {
+                return call.call();
+            } catch (Exception ex) {
+                throw new RuntimeException(ex);
             }
-            return false;
         }
     }
 }
