@@ -1,51 +1,30 @@
 /*
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
+ * Copyright (c) 1997, 2023, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
- *
- * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
- * Other names may be trademarks of their respective owners.
- *
- * The contents of this file are subject to the terms of either the GNU
- * General Public License Version 2 only ("GPL") or the Common
- * Development and Distribution License("CDDL") (collectively, the
- * "License"). You may not use this file except in compliance with the
- * License. You can obtain a copy of the License at
- * http://www.netbeans.org/cddl-gplv2.html
- * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
- * specific language governing permissions and limitations under the
- * License.  When distributing the software, include this License Header
- * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the GPL Version 2 section of the License file that
- * accompanied this code. If applicable, add the following below the
- * License Header, with the fields enclosed by brackets [] replaced by
- * your own identifying information:
- * "Portions Copyrighted [year] [name of copyright owner]"
+ * by Oracle in the LICENSE file that accompanied this code.
  *
- * Contributor(s):
- * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
- * Microsystems, Inc. All Rights Reserved.
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
  *
- * If you wish your version of this file to be governed by only the CDDL
- * or only the GPL Version 2, indicate your decision by adding
- * "[Contributor] elects to include this software in this distribution
- * under the [CDDL or GPL Version 2] license." If you do not indicate a
- * single choice of license, a recipient has the option to distribute
- * your version of this file under either the CDDL, the GPL Version 2 or
- * to extend the choice of license to its licensees as provided above.
- * However, if you add GPL Version 2 code and therefore, elected the GPL
- * Version 2 license, then the option applies only if the new code is
- * made subject to such option by the copyright holder.
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 
 package org.graalvm.visualvm.lib.common;
 
-import org.graalvm.visualvm.lib.jfluid.ProfilerEngineSettings;
-import org.graalvm.visualvm.lib.jfluid.client.ClientUtils;
-import org.graalvm.visualvm.lib.jfluid.global.CommonConstants;
 import java.util.ArrayList;
 import java.util.HashSet;
 import java.util.List;
@@ -53,8 +32,11 @@ import java.util.Map;
 import java.util.Properties;
 import java.util.ResourceBundle;
 import java.util.Set;
+import org.graalvm.visualvm.lib.jfluid.ProfilerEngineSettings;
+import org.graalvm.visualvm.lib.jfluid.client.ClientUtils;
 import org.graalvm.visualvm.lib.jfluid.filters.GenericFilter;
 import org.graalvm.visualvm.lib.jfluid.filters.JavaTypeFilter;
+import org.graalvm.visualvm.lib.jfluid.global.CommonConstants;
 
 
 /**
@@ -106,6 +88,7 @@ public class ProfilingSettings {
     public static final String PROP_INSTRUMENT_METHOD_INVOKE = "profiler.settings.instrument.method.invoke"; //NOI18N
     public static final String PROP_INSTRUMENT_SPAWNED_THREADS = "profiler.settings.instrument.spawned.threads"; //NOI18N
     public static final String PROP_N_PROFILED_THREADS_LIMIT = "profiler.settings.n.profiled.threads.limit"; //NOI18N
+    public static final String PROP_MAX_STRING_LENGTH = "profiler.settings.max.string.length"; //NOI18N
     public static final String PROP_STACK_DEPTH_LIMIT = "profiler.settings.stack.depth.limit"; //NOI18N
     public static final String PROP_SORT_RESULTS_BY_THREAD_CPU_TIME = "profiler.settings.sort.results.by.thread.cpu.time"; //NOI18N
     public static final String PROP_SAMPLING_INTERVAL = "profiler.settings.sampling.interval"; //NOI18N
@@ -168,6 +151,7 @@ public class ProfilingSettings {
     private int codeRegionCPUResBufSize = 1000;
     private int cpuProfilingType = CommonConstants.CPU_INSTR_FULL;
     private int instrScheme = CommonConstants.INSTRSCHEME_LAZY;
+    private int maxStringLength = CommonConstants.MAX_STRING_LENGTH_DEFAULT;
     private int nProfiledThreadsLimit = 32;
     private int stackDepthLimit = Integer.MAX_VALUE;
     private int profilingType = PROFILE_MONITOR;
@@ -257,9 +241,9 @@ public class ProfilingSettings {
     }
 
     /** @param cpuProfilingType Type of CPU instrumentation.
-     * @see CommonConstants.CPU_INSTR_FULL
-     * @see CommonConstants.CPU_INSTR_SAMPLED
-     * @see CommonConstants.CPU_SAMPLED
+     * @see CommonConstants#CPU_INSTR_FULL
+     * @see CommonConstants#CPU_INSTR_SAMPLED
+     * @see CommonConstants#CPU_SAMPLED
      */
     public void setCPUProfilingType(final int cpuProfilingType) {
         this.cpuProfilingType = cpuProfilingType;
@@ -268,9 +252,9 @@ public class ProfilingSettings {
     // -- General CPU Profiling settings ---------------------------------------------------------------------------------
 
     /** @return Type of CPU instrumentation
-     * @see CommonConstants.CPU_INSTR_FULL
-     * @see CommonConstants.CPU_INSTR_SAMPLED
-     * @see CommonConstants.CPU_SAMPLED
+     * @see CommonConstants#CPU_INSTR_FULL
+     * @see CommonConstants#CPU_INSTR_SAMPLED
+     * @see CommonConstants#CPU_SAMPLED
      */
     public int getCPUProfilingType() {
         return cpuProfilingType;
@@ -423,6 +407,14 @@ public class ProfilingSettings {
         return nProfiledThreadsLimit;
     }
 
+    public void setMaxStringLength(int maxLength) {
+        maxStringLength = maxLength;
+    }
+
+    public int getMaxStringLength() {
+        return maxStringLength;
+    }
+
     public void setStackDepthLimit(int num) {
         stackDepthLimit = num;
     }
@@ -593,6 +585,7 @@ public class ProfilingSettings {
             settings.setNProfiledThreadsLimit(Integer.MAX_VALUE); // zero or negative value means we do not limit it, just remember value for the UI
         }
 
+        settings.setMaxStringLength(getMaxStringLength());
         settings.setStackDepthLimit(getStackDepthLimit());
         settings.setSortResultsByThreadCPUTime(getSortResultsByThreadCPUTime());
 
@@ -650,6 +643,7 @@ public class ProfilingSettings {
         settings.setInstrumentMethodInvoke(getInstrumentMethodInvoke());
         settings.setInstrumentSpawnedThreads(getInstrumentSpawnedThreads());
         settings.setNProfiledThreadsLimit(getNProfiledThreadsLimit());
+        settings.setMaxStringLength(getMaxStringLength());
         settings.setStackDepthLimit(getStackDepthLimit());
         settings.setSortResultsByThreadCPUTime(getSortResultsByThreadCPUTime());
 
@@ -711,6 +705,8 @@ public class ProfilingSettings {
         sb.append('\n'); //NOI18N
         sb.append("nProfiledThreadsLimit: ").append(getNProfiledThreadsLimit()); //NOI18N
         sb.append('\n'); //NOI18N
+        sb.append("maxStringLength: ").append(getMaxStringLength()); //NOI18N
+        sb.append('\n'); //NOI18N
         sb.append("stackDepthLimit: ").append(getStackDepthLimit()); //NOI18N
         sb.append('\n'); //NOI18N
         sb.append("sortResultsByThreadCPUTime: ").append(getSortResultsByThreadCPUTime()); //NOI18N
@@ -782,6 +778,7 @@ public class ProfilingSettings {
         setInstrumentSpawnedThreads(Boolean.valueOf(getProperty(props, prefix + PROP_INSTRUMENT_SPAWNED_THREADS, "false"))
                                            .booleanValue()); //NOI18N
         setNProfiledThreadsLimit(Integer.parseInt(getProperty(props, prefix + PROP_N_PROFILED_THREADS_LIMIT, "32"))); //NOI18N
+        setMaxStringLength(Integer.parseInt(getProperty(props, prefix + PROP_MAX_STRING_LENGTH, Integer.toString(CommonConstants.MAX_STRING_LENGTH_DEFAULT))));
         setStackDepthLimit(Integer.parseInt(getProperty(props, prefix + PROP_STACK_DEPTH_LIMIT, String.valueOf(Integer.MAX_VALUE))));
         setSortResultsByThreadCPUTime(Boolean.valueOf(getProperty(props, prefix + PROP_SORT_RESULTS_BY_THREAD_CPU_TIME, "false"))
                                              .booleanValue()); //NOI18N
@@ -900,6 +897,7 @@ public class ProfilingSettings {
         props.put(prefix + PROP_INSTRUMENT_METHOD_INVOKE, Boolean.toString(getInstrumentMethodInvoke()));
         props.put(prefix + PROP_INSTRUMENT_SPAWNED_THREADS, Boolean.toString(getInstrumentSpawnedThreads()));
         props.put(prefix + PROP_N_PROFILED_THREADS_LIMIT, Integer.toString(getNProfiledThreadsLimit()));
+        props.put(prefix + PROP_MAX_STRING_LENGTH, Integer.toString(getMaxStringLength()));
         props.put(prefix + PROP_STACK_DEPTH_LIMIT, Integer.toString(getStackDepthLimit()));
         props.put(prefix + PROP_SORT_RESULTS_BY_THREAD_CPU_TIME, Boolean.toString(getSortResultsByThreadCPUTime()));
         props.put(prefix + PROP_SAMPLING_FREQUENCY, Integer.toString(getSamplingFrequency()));
