@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1997, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -68,6 +68,7 @@ public class IntegrationUtils {
     public static final String PLATFORM_JAVA_210 = messages.getString("IntegrationUtils_PlatformJava210"); // NOI18N
     public static final String PLATFORM_JAVA_220 = messages.getString("IntegrationUtils_PlatformJava220"); // NOI18N
     public static final String PLATFORM_JAVA_230 = messages.getString("IntegrationUtils_PlatformJava230"); // NOI18N
+    public static final String PLATFORM_JAVA_240 = messages.getString("IntegrationUtils_PlatformJava240"); // NOI18N
     public static final String PLATFORM_JAVA_CVM = messages.getString("IntegrationUtils_PlatformJavaCvm"); // NOI18N
     public static final String PLATFORM_WINDOWS_OS = messages.getString("IntegrationUtils_PlatformWindowsOs"); // NOI18N
     public static final String PLATFORM_WINDOWS_AMD64_OS = messages.getString("IntegrationUtils_PlatformWindowsAmd64Os"); // NOI18N
@@ -109,6 +110,7 @@ public class IntegrationUtils {
     private static final String JDK_210_NAME = messages.getString("IntegrationUtils_Jdk210Name"); // NOI18N
     private static final String JDK_220_NAME = messages.getString("IntegrationUtils_Jdk220Name"); // NOI18N
     private static final String JDK_230_NAME = messages.getString("IntegrationUtils_Jdk230Name"); // NOI18N
+    private static final String JDK_240_NAME = messages.getString("IntegrationUtils_Jdk240Name"); // NOI18N
     private static final String JDK_CVM_NAME = messages.getString("IntegrationUtils_JdkCvmName"); // NOI18N
     private static final String HTML_REMOTE_STRING = "&lt;" + messages.getString("IntegrationUtils_RemoteString") + "&gt;"; // NOI18N
     private static final String EXPORT_SETENV_MESSAGE = messages.getString("IntegrationUtils_ExportSetenvMessage"); // NOI18N
@@ -308,6 +310,8 @@ public class IntegrationUtils {
             return PLATFORM_JAVA_220;
         } else if (javaVersionString.equals(CommonConstants.JDK_230_STRING)) {
             return PLATFORM_JAVA_230;
+        } else if (javaVersionString.equals(CommonConstants.JDK_240_STRING)) {
+            return PLATFORM_JAVA_240;
         } else if (javaVersionString.equals(CommonConstants.JDK_CVM_STRING)) {
             return PLATFORM_JAVA_CVM;
         }
@@ -399,6 +403,8 @@ public class IntegrationUtils {
             return JDK_220_NAME;
         } else if (javaPlatform.equals(PLATFORM_JAVA_230)) {
             return JDK_230_NAME;
+        } else if (javaPlatform.equals(PLATFORM_JAVA_240)) {
+            return JDK_240_NAME;
         } else if (javaPlatform.equals(PLATFORM_JAVA_CVM)) {
             return JDK_CVM_NAME;
         }
@@ -446,6 +452,8 @@ public class IntegrationUtils {
             return "jdk16"; //NOI18N // for JDK 22 we use the same as for 6.0 for now
         } else if (javaPlatform.equals(PLATFORM_JAVA_230)) {
             return "jdk16"; //NOI18N // for JDK 23 we use the same as for 6.0 for now
+        } else if (javaPlatform.equals(PLATFORM_JAVA_240)) {
+            return "jdk16"; //NOI18N // for JDK 24 we use the same as for 6.0 for now
         } else if (javaPlatform.equals(PLATFORM_JAVA_CVM)) {
             return "cvm";  // NOI18N
         }
@@ -516,6 +524,8 @@ public class IntegrationUtils {
             return PLATFORM_JAVA_220;
         } else if (jdkVersion == Platform.JDK_230) {
             return PLATFORM_JAVA_230;
+        } else if (jdkVersion == Platform.JDK_240) {
+            return PLATFORM_JAVA_240;
         }
 
         return null;
