@@ -1,44 +1,26 @@
 /*
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
+ * Copyright (c) 1997, 2021, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
- * Copyright 1997-2020 Oracle and/or its affiliates. All rights reserved.
- *
- * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
- * Other names may be trademarks of their respective owners.
- *
- * The contents of this file are subject to the terms of either the GNU
- * General Public License Version 2 only ("GPL") or the Common
- * Development and Distribution License("CDDL") (collectively, the
- * "License"). You may not use this file except in compliance with the
- * License. You can obtain a copy of the License at
- * http://www.netbeans.org/cddl-gplv2.html
- * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
- * specific language governing permissions and limitations under the
- * License.  When distributing the software, include this License Header
- * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the GPL Version 2 section of the License file that
- * accompanied this code. If applicable, add the following below the
- * License Header, with the fields enclosed by brackets [] replaced by
- * your own identifying information:
- * "Portions Copyrighted [year] [name of copyright owner]"
+ * by Oracle in the LICENSE file that accompanied this code.
  *
- * Contributor(s):
- * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
- * Microsystems, Inc. All Rights Reserved.
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
  *
- * If you wish your version of this file to be governed by only the CDDL
- * or only the GPL Version 2, indicate your decision by adding
- * "[Contributor] elects to include this software in this distribution
- * under the [CDDL or GPL Version 2] license." If you do not indicate a
- * single choice of license, a recipient has the option to distribute
- * your version of this file under either the CDDL, the GPL Version 2 or
- * to extend the choice of license to its licensees as provided above.
- * However, if you add GPL Version 2 code and therefore, elected the GPL
- * Version 2 license, then the option applies only if the new code is
- * made subject to such option by the copyright holder.
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 
 package org.graalvm.visualvm.lib.ui;
@@ -170,7 +152,7 @@ public final class UIUtils {
         return separator;
     }
     
-    /** Determines if current L&F is AquaLookAndFeel */
+    /** Determines if current L&amp;F is AquaLookAndFeel */
     public static boolean isAquaLookAndFeel() {
         // is current L&F some kind of AquaLookAndFeel?
         return UIManager.getLookAndFeel().getID().equals("Aqua"); //NOI18N
@@ -215,31 +197,31 @@ public final class UIUtils {
         return new JLabel("X").getPreferredSize().height + 2; //NOI18N
     }
 
-    /** Determines if current L&F is GTKLookAndFeel */
+    /** Determines if current L&amp;F is GTKLookAndFeel */
     public static boolean isGTKLookAndFeel() {
         // is current L&F some kind of GTKLookAndFeel?
         return UIManager.getLookAndFeel().getID().equals("GTK"); //NOI18N
     }
     
-    /** Determines if current L&F is Nimbus */
+    /** Determines if current L&amp;F is Nimbus */
     public static boolean isNimbusLookAndFeel() {
         // is current L&F Nimbus?
         return UIManager.getLookAndFeel().getID().equals("Nimbus"); //NOI18N
     }
     
-    /** Determines if current L&F is GTK using Nimbus theme */
+    /** Determines if current L&amp;F is GTK using Nimbus theme */
     public static boolean isNimbusGTKTheme() {
         // is current L&F GTK using Nimbus theme?
         return isGTKLookAndFeel() && "nimbus".equals(Toolkit.getDefaultToolkit().getDesktopProperty("gnome.Net/ThemeName")); //NOI18N
     }
     
-    /** Determines if current L&F is Nimbus or GTK with Nimbus theme*/
+    /** Determines if current L&amp;F is Nimbus or GTK with Nimbus theme*/
     public static boolean isNimbus() {
         // is current L&F Nimbus or GTK with Nimbus theme?
         return isNimbusLookAndFeel() || isNimbusGTKTheme();
     }
 
-    /** Determines if current L&F is MetalLookAndFeel */
+    /** Determines if current L&amp;F is MetalLookAndFeel */
     public static boolean isMetalLookAndFeel() {
         // is current L&F some kind of MetalLookAndFeel?
         return UIManager.getLookAndFeel().getID().equals("Metal"); //NOI18N
@@ -310,18 +292,23 @@ public final class UIUtils {
             unfocusedSelBg = UIManager.getColor("nb.explorer.unfocusedSelBg"); //NOI18N
 
             if (unfocusedSelBg == null) {
-                //try to get standard shadow color
-                unfocusedSelBg = UIManager.getColor("controlShadow"); //NOI18N
+                // try Aqua L&F
+                unfocusedSelBg = UIManager.getColor("Table.selectionInactiveBackground"); //NOI18N
 
                 if (unfocusedSelBg == null) {
-                    //Okay, the look and feel doesn't suport it, punt
-                    unfocusedSelBg = Color.lightGray;
-                }
+                    //try to get standard shadow color
+                    unfocusedSelBg = UIManager.getColor("controlShadow"); //NOI18N
 
-                //Lighten it a bit because disabled text will use controlShadow/
-                //gray
-                if (!Color.WHITE.equals(unfocusedSelBg.brighter())) {
-                    unfocusedSelBg = unfocusedSelBg.brighter();
+                    if (unfocusedSelBg == null) {
+                        //Okay, the look and feel doesn't suport it, punt
+                        unfocusedSelBg = Color.lightGray;
+                    }
+
+                    //Lighten it a bit because disabled text will use controlShadow/
+                    //gray
+                    if (!Color.WHITE.equals(unfocusedSelBg.brighter())) {
+                        unfocusedSelBg = unfocusedSelBg.brighter();
+                    }
                 }
             }
         }
@@ -434,7 +421,7 @@ public final class UIUtils {
         return darkResultsBackground;
     }
 
-    /** Determines if current L&F is Windows Classic LookAndFeel */
+    /** Determines if current L&amp;F is Windows Classic LookAndFeel */
     public static boolean isWindowsClassicLookAndFeel() {
         if ("Windows Classic".equals(UIManager.getLookAndFeel().getName())) return true; //NOI18N
         
@@ -445,13 +432,13 @@ public final class UIUtils {
         return (!isWindowsXPLookAndFeel());
     }
 
-    /** Determines if current L&F is WindowsLookAndFeel */
+    /** Determines if current L&amp;F is WindowsLookAndFeel */
     public static boolean isWindowsLookAndFeel() {
         // is current L&F some kind of WindowsLookAndFeel?
         return UIManager.getLookAndFeel().getID().equals("Windows"); //NOI18N
     }
 
-    /** Determines if current L&F is Windows XP LookAndFeel */
+    /** Determines if current L&amp;F is Windows XP LookAndFeel */
     public static boolean isWindowsXPLookAndFeel() {
         if (!isWindowsLookAndFeel()) {
             return false;
@@ -480,7 +467,7 @@ public final class UIUtils {
     /** Checks give TreePath for the last node, and if it ends with a node with just one child,
      * it keeps expanding further.
      * Current implementation expands through the first child that is not leaf. To more correctly
-     * fulfil expected semantics in case maxChildToExpand is > 1, it should expand all paths through
+     * fulfill expected semantics in case maxChildToExpand is &gt; 1, it should expand all paths through
      * all children.
      *
      * @param tree
@@ -613,7 +600,7 @@ public final class UIUtils {
     // Also fixes buttons size in JToolbar.
 
     /** Ensures that focus will be really painted if button is focused
-     * and fixes using custom border for JDK 1.5 & XP LaF
+     * and fixes using custom border for JDK 1.5 &amp; XP L&amp;F
      */
     public static void fixButtonUI(AbstractButton button) {
         // Doesn't seem to be necessary any more, conflicts with Jigsaw
