@@ -1,44 +1,26 @@
 /*
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
+ * Copyright (c) 1997, 2024, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
- * Copyright 1997-2014 Oracle and/or its affiliates. All rights reserved.
- *
- * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
- * Other names may be trademarks of their respective owners.
- *
- * The contents of this file are subject to the terms of either the GNU
- * General Public License Version 2 only ("GPL") or the Common
- * Development and Distribution License("CDDL") (collectively, the
- * "License"). You may not use this file except in compliance with the
- * License. You can obtain a copy of the License at
- * http://www.netbeans.org/cddl-gplv2.html
- * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
- * specific language governing permissions and limitations under the
- * License.  When distributing the software, include this License Header
- * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the GPL Version 2 section of the License file that
- * accompanied this code. If applicable, add the following below the
- * License Header, with the fields enclosed by brackets [] replaced by
- * your own identifying information:
- * "Portions Copyrighted [year] [name of copyright owner]"
+ * by Oracle in the LICENSE file that accompanied this code.
  *
- * Contributor(s):
- * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
- * Microsystems, Inc. All Rights Reserved.
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
  *
- * If you wish your version of this file to be governed by only the CDDL
- * or only the GPL Version 2, indicate your decision by adding
- * "[Contributor] elects to include this software in this distribution
- * under the [CDDL or GPL Version 2] license." If you do not indicate a
- * single choice of license, a recipient has the option to distribute
- * your version of this file under either the CDDL, the GPL Version 2 or
- * to extend the choice of license to its licensees as provided above.
- * However, if you add GPL Version 2 code and therefore, elected the GPL
- * Version 2 license, then the option applies only if the new code is
- * made subject to such option by the copyright holder.
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 
 package org.graalvm.visualvm.lib.ui.jdbc;
@@ -69,6 +51,8 @@ import org.graalvm.visualvm.lib.jfluid.results.cpu.PrestimeCPUCCTNode;
 import org.graalvm.visualvm.lib.jfluid.results.jdbc.JdbcCCTProvider;
 import org.graalvm.visualvm.lib.jfluid.results.jdbc.JdbcResultsSnapshot;
 import org.graalvm.visualvm.lib.jfluid.results.memory.PresoObjAllocCCTNode;
+import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
+import org.graalvm.visualvm.lib.profiler.api.icons.ProfilerIcons;
 import org.graalvm.visualvm.lib.ui.swing.ExportUtils;
 import org.graalvm.visualvm.lib.ui.swing.PopupButton;
 import org.graalvm.visualvm.lib.ui.swing.ProfilerTable;
@@ -81,8 +65,6 @@ import org.graalvm.visualvm.lib.ui.swing.renderer.LabelRenderer;
 import org.graalvm.visualvm.lib.ui.swing.renderer.McsTimeRenderer;
 import org.graalvm.visualvm.lib.ui.swing.renderer.NumberPercentRenderer;
 import org.graalvm.visualvm.lib.ui.swing.renderer.NumberRenderer;
-import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
-import org.graalvm.visualvm.lib.profiler.api.icons.ProfilerIcons;
 
 /**
  *
@@ -105,7 +87,7 @@ abstract class JDBCTreeTableView extends JDBCView {
     private boolean searchCallerMethods = false;
     
     
-    public JDBCTreeTableView(Set<ClientUtils.SourceCodeSelection> selection, boolean reverse) {
+    JDBCTreeTableView(Set<ClientUtils.SourceCodeSelection> selection, boolean reverse) {
         initUI();
     }
     
@@ -162,6 +144,7 @@ abstract class JDBCTreeTableView extends JDBCView {
         renderers[1].setMaxValue(__totalObjects);
         renderers[0].setDiffMode(diff);
         renderers[1].setDiffMode(diff);
+        timeRenderer.setDiffMode(diff);
         treeTableModel.setRoot(PresoObjAllocCCTNode.rootNode(nodes.toArray(new PresoObjAllocCCTNode[0])));
 
         currentData = newData;
@@ -172,6 +155,7 @@ abstract class JDBCTreeTableView extends JDBCView {
         renderers[1].setMaxValue(0);
         renderers[0].setDiffMode(false);
         renderers[1].setDiffMode(false);
+        timeRenderer.setDiffMode(false);
 
         treeTableModel.setRoot(PresoObjAllocCCTNode.rootNode(new PresoObjAllocCCTNode[0]));
 
@@ -210,6 +194,7 @@ abstract class JDBCTreeTableView extends JDBCView {
     
     
     private HideableBarRenderer[] renderers;
+    private McsTimeRenderer timeRenderer;
     
     HideableBarRenderer.BarDiffMode barDiffMode() {
         return HideableBarRenderer.BarDiffMode.MODE_BAR_DIFF;
@@ -255,6 +240,7 @@ abstract class JDBCTreeTableView extends JDBCView {
         renderers[0].setBarDiffMode(barDiffMode);
         renderers[1] = new HideableBarRenderer(new NumberRenderer());
         renderers[1].setBarDiffMode(barDiffMode);
+        timeRenderer = new McsTimeRenderer();
         
         long refTime = 123456;
         renderers[0].setMaxValue(refTime);
@@ -267,16 +253,18 @@ abstract class JDBCTreeTableView extends JDBCView {
         treeTable.setDefaultColumnWidth(1, renderers[0].getOptimalWidth());
         treeTable.setDefaultColumnWidth(2, renderers[1].getMaxNoBarWidth());
         
+        LabelRenderer tr = new LabelRenderer();
+        tr.setHorizontalAlignment(LabelRenderer.TRAILING);
+        tr.setValue("X"+treeTableModel.getColumnName(3)+"X", -1);       // NOI18N
+        treeTable.setColumnRenderer(3, timeRenderer);
+        treeTable.setDefaultColumnWidth(3, tr.getPreferredSize().width);
+        treeTable.setColumnVisibility(3, false);
+
         // Debug columns
         LabelRenderer lr = new LabelRenderer();
         lr.setHorizontalAlignment(LabelRenderer.TRAILING);
         lr.setValue("XStatement TypeX", -1);
         
-        treeTable.setColumnRenderer(3, lr);
-        treeTable.setDefaultSortOrder(3, SortOrder.ASCENDING);
-        treeTable.setDefaultColumnWidth(3, lr.getPreferredSize().width);
-        treeTable.setColumnVisibility(3, false);
-        
         treeTable.setColumnRenderer(4, lr);
         treeTable.setDefaultSortOrder(4, SortOrder.ASCENDING);
         treeTable.setDefaultColumnWidth(4, lr.getPreferredSize().width);
@@ -287,6 +275,11 @@ abstract class JDBCTreeTableView extends JDBCView {
         treeTable.setDefaultColumnWidth(5, lr.getPreferredSize().width);
         treeTable.setColumnVisibility(5, false);
         
+        treeTable.setColumnRenderer(6, lr);
+        treeTable.setDefaultSortOrder(6, SortOrder.ASCENDING);
+        treeTable.setDefaultColumnWidth(6, lr.getPreferredSize().width);
+        treeTable.setColumnVisibility(6, false);
+
         ProfilerTableContainer tableContainer = new ProfilerTableContainer(treeTable, false, null);
         
         setLayout(new BorderLayout());
@@ -325,7 +318,8 @@ abstract class JDBCTreeTableView extends JDBCView {
                                         INVOCATIONS_COLUMN_TOOLTIP,
                                         COMMANDS_COLUMN_TOOLTIP,
                                         TABLES_COLUMN_TOOLTIP,
-                                        STATEMENTS_COLUMN_TOOLTIP
+                                        STATEMENTS_COLUMN_TOOLTIP,
+                                        AVERAGE_COLUMN_TOOLTIP
                                     });
     }
     
@@ -427,11 +421,13 @@ abstract class JDBCTreeTableView extends JDBCView {
                 return COLUMN_TOTALTIME;
             } else if (columnIndex == 2) {
                 return COLUMN_INVOCATIONS;
-            }  else if (columnIndex == 3) {
-                return COLUMN_COMMANDS;
+            } else if (columnIndex == 3) {
+                return COLUMN_AVEGARE;
             } else if (columnIndex == 4) {
-                return COLUMN_TABLES;
+                return COLUMN_COMMANDS;
             } else if (columnIndex == 5) {
+                return COLUMN_TABLES;
+            } else if (columnIndex == 6) {
                 return COLUMN_STATEMENTS;
             }
             return null;
@@ -445,17 +441,19 @@ abstract class JDBCTreeTableView extends JDBCView {
             } else if (columnIndex == 2) {
                 return Integer.class;
             } else if (columnIndex == 3) {
-                return String.class;
+                return Long.class;
             } else if (columnIndex == 4) {
                 return String.class;
             } else if (columnIndex == 5) {
                 return String.class;
+            } else if (columnIndex == 6) {
+                return String.class;
             }
             return Long.class;
         }
 
         public int getColumnCount() {
-            return 6;
+            return 7;
         }
 
         public Object getValueAt(TreeNode node, int columnIndex) {
@@ -467,19 +465,21 @@ abstract class JDBCTreeTableView extends JDBCView {
             } else if (columnIndex == 2) {
                 return jdbcNode.nCalls;
             } else if (columnIndex == 3) {
+                return jdbcNode.totalObjSize/jdbcNode.nCalls;
+            } else if (columnIndex == 4) {
                 if (jdbcNode instanceof SQLQueryNode) {
                     return commandString(((SQLQueryNode)jdbcNode).getCommandType());
                 } else {
                     return "-"; // NOI18N
                 }
                 
-            } else if (columnIndex == 4) {
+            } else if (columnIndex == 5) {
                 if (jdbcNode instanceof SQLQueryNode) {
                     return formatTables(((SQLQueryNode)jdbcNode).getTables());
                 } else {
                     return "-"; // NOI18N
                 }
-            } else if (columnIndex == 5) {
+            } else if (columnIndex == 6) {
                 if (jdbcNode instanceof SQLQueryNode) {
                     switch (((SQLQueryNode)jdbcNode).getStatementType()) {
                         case JdbcCCTProvider.SQL_PREPARED_STATEMENT: return STATEMENT_PREPARED;
