@@ -1,44 +1,26 @@
 /*
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
+ * Copyright (c) 1997, 2022, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
- * Copyright 1997-2020 Oracle and/or its affiliates. All rights reserved.
- *
- * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
- * Other names may be trademarks of their respective owners.
- *
- * The contents of this file are subject to the terms of either the GNU
- * General Public License Version 2 only ("GPL") or the Common
- * Development and Distribution License("CDDL") (collectively, the
- * "License"). You may not use this file except in compliance with the
- * License. You can obtain a copy of the License at
- * http://www.netbeans.org/cddl-gplv2.html
- * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
- * specific language governing permissions and limitations under the
- * License.  When distributing the software, include this License Header
- * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the GPL Version 2 section of the License file that
- * accompanied this code. If applicable, add the following below the
- * License Header, with the fields enclosed by brackets [] replaced by
- * your own identifying information:
- * "Portions Copyrighted [year] [name of copyright owner]"
+ * by Oracle in the LICENSE file that accompanied this code.
  *
- * Contributor(s):
- * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
- * Microsystems, Inc. All Rights Reserved.
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
  *
- * If you wish your version of this file to be governed by only the CDDL
- * or only the GPL Version 2, indicate your decision by adding
- * "[Contributor] elects to include this software in this distribution
- * under the [CDDL or GPL Version 2] license." If you do not indicate a
- * single choice of license, a recipient has the option to distribute
- * your version of this file under either the CDDL, the GPL Version 2 or
- * to extend the choice of license to its licensees as provided above.
- * However, if you add GPL Version 2 code and therefore, elected the GPL
- * Version 2 license, then the option applies only if the new code is
- * made subject to such option by the copyright holder.
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 
 package org.graalvm.visualvm.lib.ui.swing;
@@ -75,6 +57,7 @@ import javax.swing.RowSorter;
 import javax.swing.SortOrder;
 import javax.swing.SwingUtilities;
 import javax.swing.UIManager;
+import javax.swing.border.Border;
 import javax.swing.event.ListSelectionEvent;
 import javax.swing.event.ListSelectionListener;
 import javax.swing.event.TreeExpansionEvent;
@@ -93,6 +76,7 @@ import javax.swing.table.TableColumnModel;
 import javax.swing.table.TableModel;
 import javax.swing.table.TableRowSorter;
 import javax.swing.tree.DefaultMutableTreeNode;
+import javax.swing.tree.DefaultTreeCellRenderer;
 import javax.swing.tree.DefaultTreeModel;
 import javax.swing.tree.ExpandVetoException;
 import javax.swing.tree.TreeCellRenderer;
@@ -456,6 +440,7 @@ public class ProfilerTreeTable extends ProfilerTable {
         
     }
     
+    public static interface DeleteNodes {}
     
     public void setCellRenderer(TreeCellRenderer renderer) {
         if (tree != null) {
@@ -976,6 +961,7 @@ public class ProfilerTreeTable extends ProfilerTable {
         private List filteredChildren(Object parent) {
             if (cache == null) cache = new HashMap();
             
+            boolean createFilteredNode = !(filter instanceof DeleteNodes);
             TreeNode tParent = (TreeNode)parent;
             TreePathKey parentKey = new TreePathKey(getPathToRoot(tParent));
             List children = cache.get(parentKey);
@@ -993,7 +979,7 @@ public class ProfilerTreeTable extends ProfilerTable {
                     else entry.setContext(renderer.toString(), child);
                     if (filter.include(entry)) {
                         children.add(child);
-                    } else if (parent instanceof CCTNode) {
+                    } else if (createFilteredNode && parent instanceof CCTNode) {
                         if (filtered == null) filtered = ((CCTNode)child).createFilteredNode();
                         else filtered.merge((CCTNode)child);
                     }
@@ -1522,8 +1508,8 @@ public class ProfilerTreeTable extends ProfilerTable {
         public void setSelectionPaths(TreePath[] paths) {
             if (changingModel && paths != null) {
                 List<TreePath> similarPaths = new ArrayList();
-                for (int i = 0; i < paths.length; i++) {
-                    TreePath similarPath = getSimilarPath(paths[i]);
+                for (TreePath path : paths) {
+                    TreePath similarPath = getSimilarPath(path);
                     if (similarPath != null) similarPaths.add(similarPath);
                 }
                 super.setSelectionPaths(similarPaths.toArray(new TreePath[0]));
@@ -1644,6 +1630,7 @@ public class ProfilerTreeTable extends ProfilerTable {
                     super.drawCentered(c, image[0].getGraphics(), icon, w / 2, h / 2);
                 }
             });
+            fixBorder(tree);
             
             // Expanded
             tree.expandRow(0);
@@ -1670,8 +1657,19 @@ public class ProfilerTreeTable extends ProfilerTable {
             ICONS[3] = new ImageIcon(image[0]);
             
         }
-        
-            
+
+        private static void fixBorder(JTree tree) {
+            TreeCellRenderer cellRenderer = tree.getCellRenderer();
+            if (cellRenderer instanceof DefaultTreeCellRenderer) {
+                DefaultTreeCellRenderer defaultRenderer = (DefaultTreeCellRenderer) cellRenderer;
+                Border treeBorder = defaultRenderer.getBorder();
+                Insets i = treeBorder.getBorderInsets(defaultRenderer);
+                if (i.bottom + i.left + i.right + i.top == 0) {
+                    defaultRenderer.setBorder(BorderFactory.createEmptyBorder(1, 1, 1, 1));
+                }
+            }
+        }
+
         private boolean isSelected;
         
         void setSelected(boolean selected) { isSelected = selected; }
