@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1997, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -94,6 +94,7 @@ public interface CommonConstants {
     public static final int JDK_210 = 19;
     public static final int JDK_220 = 20;
     public static final int JDK_230 = 21;
+    public static final int JDK_240 = 22;
     public static final int JDK_CVM = 5;
     public static final int JDK_UNSUPPORTED = -1;
 
@@ -117,6 +118,7 @@ public interface CommonConstants {
     public static final String JDK_210_STRING = "jdk210"; // NOI18N
     public static final String JDK_220_STRING = "jdk220"; // NOI18N
     public static final String JDK_230_STRING = "jdk230"; // NOI18N
+    public static final String JDK_240_STRING = "jdk240"; // NOI18N
     public static final String JDK_CVM_STRING = "cvm";  // NOI18N
     public static final String JDK_UNSUPPORTED_STRING = "UNSUPPORTED_JDK"; // NOI18N
 
