@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1997, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -307,6 +307,8 @@ public class Platform implements CommonConstants {
             jdkVersion = JDK_220;
         } else if (isJavaVersion(javaVersion,"23")) { // NOI18N
             jdkVersion = JDK_230;
+        } else if (isJavaVersion(javaVersion,"24")) { // NOI18N
+            jdkVersion = JDK_240;
         } else if (javaVersion.equals("CVM")) { // NOI18N
             jdkVersion = JDK_CVM;
         } else {
@@ -361,6 +363,7 @@ public class Platform implements CommonConstants {
             case JDK_210: return JDK_210_STRING;
             case JDK_220: return JDK_220_STRING;
             case JDK_230: return JDK_230_STRING;
+            case JDK_240: return JDK_240_STRING;
             case JDK_CVM: return JDK_CVM_STRING;
             case JDK_UNSUPPORTED: return JDK_UNSUPPORTED_STRING;
         }
