@@ -1,44 +1,26 @@
 /*
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
+ * Copyright (c) 1997, 2022, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
- *
- * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
- * Other names may be trademarks of their respective owners.
- *
- * The contents of this file are subject to the terms of either the GNU
- * General Public License Version 2 only ("GPL") or the Common
- * Development and Distribution License("CDDL") (collectively, the
- * "License"). You may not use this file except in compliance with the
- * License. You can obtain a copy of the License at
- * http://www.netbeans.org/cddl-gplv2.html
- * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
- * specific language governing permissions and limitations under the
- * License.  When distributing the software, include this License Header
- * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the GPL Version 2 section of the License file that
- * accompanied this code. If applicable, add the following below the
- * License Header, with the fields enclosed by brackets [] replaced by
- * your own identifying information:
- * "Portions Copyrighted [year] [name of copyright owner]"
+ * by Oracle in the LICENSE file that accompanied this code.
  *
- * Contributor(s):
- * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
- * Microsystems, Inc. All Rights Reserved.
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
  *
- * If you wish your version of this file to be governed by only the CDDL
- * or only the GPL Version 2, indicate your decision by adding
- * "[Contributor] elects to include this software in this distribution
- * under the [CDDL or GPL Version 2] license." If you do not indicate a
- * single choice of license, a recipient has the option to distribute
- * your version of this file under either the CDDL, the GPL Version 2 or
- * to extend the choice of license to its licensees as provided above.
- * However, if you add GPL Version 2 code and therefore, elected the GPL
- * Version 2 license, then the option applies only if the new code is
- * made subject to such option by the copyright holder.
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 
 package org.graalvm.visualvm.lib.jfluid.results.cpu;
@@ -72,7 +54,7 @@ public abstract class PrestimeCPUCCTNode extends CCTNode implements Cloneable {
         ResourceBundle messages = ResourceBundle.getBundle("org.graalvm.visualvm.lib.jfluid.results.cpu.Bundle"); // NOI18N
         SELF_TIME_STRING = messages.getString("PrestimeCPUCCTNode_SelfTimeString"); // NOI18N
     }
-    
+
     protected static final char MASK_SELF_TIME_NODE = 0x1;
     protected static final char MASK_CONTEXT_CALLS_NODE = 0x2;
     protected static final char MASK_THREAD_NODE = 0x4;
@@ -81,8 +63,8 @@ public abstract class PrestimeCPUCCTNode extends CCTNode implements Cloneable {
     public static final int SORT_BY_TIME_0 = 2;
     public static final int SORT_BY_TIME_1 = 3;
     public static final int SORT_BY_INVOCATIONS = 4;
-    
-    
+
+
     public static final PrestimeCPUCCTNode EMPTY = new PrestimeCPUCCTNode() {
         PrestimeCPUCCTNode createCopy() { return null; }
         
@@ -196,7 +178,7 @@ public abstract class PrestimeCPUCCTNode extends CCTNode implements Cloneable {
             addTotalTime1(_node.getTotalTime1());
             addWaitTime0(_node.getWaitTime0());
 
-            List<CCTNode> ch = new ArrayList();
+            List<PrestimeCPUCCTNode> ch = new ArrayList();
             
             // Include current children
             PrestimeCPUCCTNode[] _children = (PrestimeCPUCCTNode[])getChildren();
@@ -206,7 +188,7 @@ public abstract class PrestimeCPUCCTNode extends CCTNode implements Cloneable {
             // Add or merge new children
             PrestimeCPUCCTNode[] __children = (PrestimeCPUCCTNode[])node.getChildren();
             if (__children != null) for (PrestimeCPUCCTNode child : __children) {
-                if (child != null && !child.isSelfTimeNode()) {
+                if (child != null) {
                     int idx = ch.indexOf(child);
                     if (idx == -1) ch.add(child.createCopy());
                     else ch.get(idx).merge(child);
