@@ -1,43 +1,26 @@
 /*
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
+ * Copyright (c) 2016, 2022, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
- * Copyright 2016 Oracle and/or its affiliates. All rights reserved.
- *
- * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
- * Other names may be trademarks of their respective owners.
- *
- * The contents of this file are subject to the terms of either the GNU
- * General Public License Version 2 only ("GPL") or the Common
- * Development and Distribution License("CDDL") (collectively, the
- * "License"). You may not use this file except in compliance with the
- * License. You can obtain a copy of the License at
- * http://www.netbeans.org/cddl-gplv2.html
- * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
- * specific language governing permissions and limitations under the
- * License.  When distributing the software, include this License Header
- * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the GPL Version 2 section of the License file that
- * accompanied this code. If applicable, add the following below the
- * License Header, with the fields enclosed by brackets [] replaced by
- * your own identifying information:
- * "Portions Copyrighted [year] [name of copyright owner]"
+ * by Oracle in the LICENSE file that accompanied this code.
  *
- * If you wish your version of this file to be governed by only the CDDL
- * or only the GPL Version 2, indicate your decision by adding
- * "[Contributor] elects to include this software in this distribution
- * under the [CDDL or GPL Version 2] license." If you do not indicate a
- * single choice of license, a recipient has the option to distribute
- * your version of this file under either the CDDL, the GPL Version 2 or
- * to extend the choice of license to its licensees as provided above.
- * However, if you add GPL Version 2 code and therefore, elected the GPL
- * Version 2 license, then the option applies only if the new code is
- * made subject to such option by the copyright holder.
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
  *
- * Contributor(s):
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
  *
- * Portions Copyrighted 2016 Sun Microsystems, Inc.
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 package org.graalvm.visualvm.lib.jfluid.results.jdbc;
 
@@ -331,8 +314,8 @@ public class JdbcResultsSnapshot extends ResultsSnapshot {
             out.writeInt(typeForSelectId[i]);
             out.writeInt(commandTypeForSelectId[i]);
             out.writeInt(tablesForSelectId[i].length);
-            for (int j = 0; j < tablesForSelectId[i].length; j++) {
-                out.writeUTF(tablesForSelectId[i][j]);
+            for (String item : tablesForSelectId[i]) {
+                out.writeUTF(item);
             }
         }
 
@@ -342,14 +325,14 @@ public class JdbcResultsSnapshot extends ResultsSnapshot {
             out.writeInt(stacksForSelects.length);
 
             //.err.println("Stored len: " +stacksForSelects.length);
-            for (int i = 0; i < stacksForSelects.length; i++) {
-                if (stacksForSelects[i] == null) {
+            for (RuntimeMemoryCCTNode stacksForSelect : stacksForSelects) {
+                if (stacksForSelect == null) {
                     //System.err.println("  [" + i + "] = 0");
                     out.writeInt(0);
                 } else {
-                    out.writeInt(stacksForSelects[i].getType());
+                    out.writeInt(stacksForSelect.getType());
                     //System.err.println("  [" + i + "] = " + stacksForSelects[i].getType());
-                    stacksForSelects[i].writeToStream(out);
+                    stacksForSelect.writeToStream(out);
                 }
             }
 
@@ -407,7 +390,7 @@ public class JdbcResultsSnapshot extends ResultsSnapshot {
                         updateTime(stacksForSelects[i], timePerSelectId[i]/invocationsPerSelectId[i]);
                     }
                 }
-                table = new JMethodIdTable(JMethodIdTable.getDefault());
+                table = new JMethodIdTable(client.getJMethodIdTable());
             }
         } else {
             selectNames = new String[0];
@@ -415,9 +398,7 @@ public class JdbcResultsSnapshot extends ResultsSnapshot {
     }
 
     private boolean checkContainsStacks(RuntimeMemoryCCTNode[] stacksForSelects) {
-        for (int i = 0; i < stacksForSelects.length; i++) {
-            RuntimeMemoryCCTNode stacksForSelect = stacksForSelects[i];
-
+        for (RuntimeMemoryCCTNode stacksForSelect : stacksForSelects) {
             if (stacksForSelect == null) {
                 continue;
             }
@@ -464,8 +445,8 @@ public class JdbcResultsSnapshot extends ResultsSnapshot {
                 } else {
                     RuntimeMemoryCCTNode[] ar = (RuntimeMemoryCCTNode[]) n.children;
 
-                    for (int j = 0; j < ar.length; j++) {
-                        nodes.push(ar[j]);
+                    for (RuntimeMemoryCCTNode ar1 : ar) {
+                        nodes.push(ar1);
                     }
                 }
             }
