@@ -1,44 +1,26 @@
 /*
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
+ * Copyright (c) 1997, 2022, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
- *
- * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
- * Other names may be trademarks of their respective owners.
- *
- * The contents of this file are subject to the terms of either the GNU
- * General Public License Version 2 only ("GPL") or the Common
- * Development and Distribution License("CDDL") (collectively, the
- * "License"). You may not use this file except in compliance with the
- * License. You can obtain a copy of the License at
- * http://www.netbeans.org/cddl-gplv2.html
- * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
- * specific language governing permissions and limitations under the
- * License.  When distributing the software, include this License Header
- * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the GPL Version 2 section of the License file that
- * accompanied this code. If applicable, add the following below the
- * License Header, with the fields enclosed by brackets [] replaced by
- * your own identifying information:
- * "Portions Copyrighted [year] [name of copyright owner]"
+ * by Oracle in the LICENSE file that accompanied this code.
  *
- * Contributor(s):
- * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
- * Microsystems, Inc. All Rights Reserved.
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
  *
- * If you wish your version of this file to be governed by only the CDDL
- * or only the GPL Version 2, indicate your decision by adding
- * "[Contributor] elects to include this software in this distribution
- * under the [CDDL or GPL Version 2] license." If you do not indicate a
- * single choice of license, a recipient has the option to distribute
- * your version of this file under either the CDDL, the GPL Version 2 or
- * to extend the choice of license to its licensees as provided above.
- * However, if you add GPL Version 2 code and therefore, elected the GPL
- * Version 2 license, then the option applies only if the new code is
- * made subject to such option by the copyright holder.
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 
 package org.graalvm.visualvm.lib.jfluid.results.memory;
@@ -161,7 +143,7 @@ public class PresoObjAllocCCTNode extends CCTNode {
             nCalls += _node.nCalls;
             totalObjSize += _node.totalObjSize;
 
-            List<CCTNode> ch = new ArrayList();
+            List<PresoObjAllocCCTNode> ch = new ArrayList();
             
             // Include current children
             if (children != null) ch.addAll(Arrays.asList(children));
@@ -192,13 +174,13 @@ public class PresoObjAllocCCTNode extends CCTNode {
             return; // Can happen if this is called too early
         }
 
-        for (int i = 0; i < allStackRoots.length; i++) {
-            if (allStackRoots[i] != null) {
-                checkMethodIdForNodeFromVM(allStackRoots[i]);
+        JMethodIdTable table = profilerClient.getJMethodIdTable();
+        for (RuntimeMemoryCCTNode allStackRoot : allStackRoots) {
+            if (allStackRoot != null) {
+                checkMethodIdForNodeFromVM(table, allStackRoot);
             }
         }
-
-        JMethodIdTable.getDefault().getNamesForMethodIds(profilerClient);
+        table.getNamesForMethodIds(profilerClient);
     }
 
     public static PresoObjAllocCCTNode createPresentationCCTFromSnapshot(JMethodIdTable methodIdTable,
@@ -377,9 +359,10 @@ public class PresoObjAllocCCTNode extends CCTNode {
     protected static void assignNamesToNodesFromVM(ProfilerClient profilerClient, PresoObjAllocCCTNode rootNode,
                                                    String classTypeName)
                                             throws ClientUtils.TargetAppOrVMTerminated {
-        JMethodIdTable.getDefault().getNamesForMethodIds(profilerClient);
+        JMethodIdTable table = profilerClient.getJMethodIdTable();
+        table.getNamesForMethodIds(profilerClient);
         rootNode.className = StringUtils.userFormClassName(classTypeName);
-        rootNode.setFullClassAndMethodInfo(JMethodIdTable.getDefault());
+        rootNode.setFullClassAndMethodInfo(table);
     }
 
     protected static PresoObjAllocCCTNode generateMirrorNode(RuntimeMemoryCCTNode rtNode) {
@@ -439,8 +422,8 @@ public class PresoObjAllocCCTNode extends CCTNode {
             // Determine the number of non-null children and create a new children array
             int newLen = 0;
 
-            for (int i = 0; i < children.length; i++) {
-                newLen += ((children[i] != null) ? 1 : 0);
+            for (PresoObjAllocCCTNode children1 : children) {
+                newLen += ((children1 != null) ? 1 : 0);
             }
 
             boolean hasNonNullChildren = (newLen > 0);
@@ -451,9 +434,9 @@ public class PresoObjAllocCCTNode extends CCTNode {
                 PresoObjAllocCCTNode[] newChildren = new PresoObjAllocCCTNode[newLen];
                 int idx = 0;
 
-                for (int i = 0; i < children.length; i++) {
-                    if (children[i] != null) {
-                        newChildren[idx++] = children[i];
+                for (PresoObjAllocCCTNode children1 : children) {
+                    if (children1 != null) {
+                        newChildren[idx++] = children1;
                     }
                 }
 
@@ -472,21 +455,21 @@ public class PresoObjAllocCCTNode extends CCTNode {
         }
     }
 
-    protected static void checkMethodIdForNodeFromVM(RuntimeMemoryCCTNode rtNode) {
+    protected static void checkMethodIdForNodeFromVM(JMethodIdTable table, RuntimeMemoryCCTNode rtNode) {
         if (rtNode.methodId != 0) {
-            JMethodIdTable.getDefault().checkMethodId(rtNode.methodId);
+            table.checkMethodId(rtNode.methodId);
         }
 
         Object nodeChildren = rtNode.children;
 
         if (nodeChildren != null) {
             if (nodeChildren instanceof RuntimeMemoryCCTNode) {
-                checkMethodIdForNodeFromVM((RuntimeMemoryCCTNode) nodeChildren);
+                checkMethodIdForNodeFromVM(table, (RuntimeMemoryCCTNode) nodeChildren);
             } else {
                 RuntimeMemoryCCTNode[] ar = (RuntimeMemoryCCTNode[]) nodeChildren;
 
-                for (int i = 0; i < ar.length; i++) {
-                    checkMethodIdForNodeFromVM(ar[i]);
+                for (RuntimeMemoryCCTNode ar1 : ar) {
+                    checkMethodIdForNodeFromVM(table, ar1);
                 }
             }
         }
@@ -623,8 +606,8 @@ public class PresoObjAllocCCTNode extends CCTNode {
         eDD.dumpData(result); //dumps the current row
         // children nodes
         if (children!=null) {
-            for (int i = 0; i < children.length; i++) {
-                children[i].exportHTMLData(eDD, depth+1);
+            for (PresoObjAllocCCTNode children1 : children) {
+                children1.exportHTMLData(eDD, depth+1);
             }
         }
     }
@@ -663,8 +646,8 @@ public class PresoObjAllocCCTNode extends CCTNode {
         eDD.dumpData(result); //dumps the current row
         // children nodes
         if (children!=null) {
-            for (int i = 0; i < children.length; i++) {
-                children[i].exportCSVData(separator, depth+1, eDD);
+            for (PresoObjAllocCCTNode children1 : children) {
+                children1.exportCSVData(separator, depth+1, eDD);
             }
         }
     }
