@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -42,15 +42,13 @@ import org.graalvm.visualvm.lib.profiler.oql.engine.api.OQLEngine;
 import org.graalvm.visualvm.lib.profiler.oql.engine.api.ReferenceChain;
 import org.openide.util.Enumerations;
 
-/**
- *
- * @author      Jaroslav Bachorik
- */
 /**
  * A helper class for OQL engine allowing easy access to the underlying
  * heapwalker model
+ * 
+ * @author      Jaroslav Bachorik
  */
-public class Snapshot {
+public final class Snapshot {
 
     private static final String BOOLEAN_CODE = "Z"; // NOI18N
     private static final String CHAR_CODE = "C"; // NOI18N
