@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -525,6 +525,8 @@ final class ApplicationProfilerView extends DataSourceView {
                     lastInstrValue = -1;
                     if (!applicationTerminated) {
                         timer.stop();
+                        profiler.removeProfilingStateListener(MasterViewSupport.this);
+                        if (results != null) results.cleanup();
                         statusValueLabel.setText(NbBundle.getMessage(ApplicationProfilerView.class, "MSG_profiling_inactive"));    // NOI18N
                         resetControlButtons();
                         VisualVM.getInstance().runTask(new Runnable() {
@@ -585,6 +587,7 @@ final class ApplicationProfilerView extends DataSourceView {
                     timer.stop();
                     statusValueLabel.setText(NbBundle.getMessage(ApplicationProfilerView.class, "MSG_profiling_stopped")); // NOI18N
                     profiler.removeProfilingStateListener(MasterViewSupport.this);
+                    if (results != null) results.cleanup();
                     break;
                 }
               }
