@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2007, 2022, Oracle and/or its affiliates. All rights reserved.
+ *  Copyright (c) 2007, 2023, Oracle and/or its affiliates. All rights reserved.
  *  DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  * 
  *  This code is free software; you can redistribute it and/or modify it
@@ -130,19 +130,23 @@ class CPULivePanel extends ProfilingResultsSupport.ResultsView {
                     }
 //                } catch (ClientUtils.TargetAppOrVMTerminated ex) {
                 } catch (Throwable t) {
-                    if (updater != null) {
-                        updater.cleanup();
-                        updater = null;
-                    }
-
-                    if (resetter != null) {
-                        resetter.unregisterView(CPULivePanel.this);
-                        resetter = null;
-                    }
+                    cleanup();
                 }
             }
         });
     }
+
+    void cleanup() {
+        if (updater != null) {
+            updater.cleanup();
+            updater = null;
+        }
+
+        if (resetter != null) {
+            resetter.unregisterView(CPULivePanel.this);
+            resetter = null;
+        }
+    }
     
     
     // -------------------------------------------------------------------------
