@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  * 
  * This code is free software; you can redistribute it and/or modify it
@@ -86,7 +86,6 @@ import org.graalvm.visualvm.threaddump.ThreadDumpSupport;
 import org.graalvm.visualvm.tools.jmx.JmxModel;
 import org.graalvm.visualvm.tools.jmx.JmxModelFactory;
 import org.graalvm.visualvm.tools.jmx.JvmMXBeans;
-import org.graalvm.visualvm.tools.jmx.JvmMXBeansFactory;
 import org.graalvm.visualvm.uisupport.HTMLLabel;
 import org.graalvm.visualvm.uisupport.HTMLTextArea;
 import org.openide.DialogDisplayer;
@@ -629,7 +628,7 @@ final class SamplerImpl {
                 MemoryMXBean memoryBean = null;
                 JmxModel jmxModel = JmxModelFactory.getJmxModelFor(application);
                 if (jmxModel != null && jmxModel.getConnectionState() == JmxModel.ConnectionState.CONNECTED) {
-                    JvmMXBeans mxbeans = JvmMXBeansFactory.getJvmMXBeans(jmxModel);
+                    JvmMXBeans mxbeans = jmxModel.getJvmMXBeans();
                     if (mxbeans != null) {
                         memoryBean = mxbeans.getMemoryMXBean();
                     }
