@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  * 
  * This code is free software; you can redistribute it and/or modify it
@@ -25,11 +25,6 @@
 
 package org.graalvm.visualvm.sampler.truffle.memory;
 
-import org.graalvm.visualvm.application.Application;
-import org.graalvm.visualvm.application.jvm.HeapHistogram.ClassInfo;
-import org.graalvm.visualvm.profiling.actions.ProfiledSourceSelection;
-import org.graalvm.visualvm.profiling.actions.ProfilerPopupCustomizer;
-import org.graalvm.visualvm.sampler.truffle.AbstractSamplerSupport;
 import java.awt.BorderLayout;
 import java.awt.Component;
 import java.awt.Container;
@@ -66,6 +61,15 @@ import javax.swing.SortOrder;
 import javax.swing.SwingUtilities;
 import javax.swing.UIManager;
 import javax.swing.table.AbstractTableModel;
+import org.graalvm.visualvm.application.Application;
+import org.graalvm.visualvm.application.jvm.HeapHistogram.ClassInfo;
+import org.graalvm.visualvm.lib.jfluid.utils.Wildcards;
+import org.graalvm.visualvm.lib.profiler.api.ActionsSupport;
+import org.graalvm.visualvm.lib.profiler.api.GoToSource;
+import org.graalvm.visualvm.lib.profiler.api.icons.GeneralIcons;
+import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
+import org.graalvm.visualvm.lib.profiler.api.icons.LanguageIcons;
+import org.graalvm.visualvm.lib.profiler.api.icons.ProfilerIcons;
 import org.graalvm.visualvm.lib.ui.Formatters;
 import org.graalvm.visualvm.lib.ui.components.ProfilerToolbar;
 import org.graalvm.visualvm.lib.ui.swing.FilterUtils;
@@ -76,13 +80,9 @@ import org.graalvm.visualvm.lib.ui.swing.SearchUtils;
 import org.graalvm.visualvm.lib.ui.swing.renderer.HideableBarRenderer;
 import org.graalvm.visualvm.lib.ui.swing.renderer.JavaNameRenderer;
 import org.graalvm.visualvm.lib.ui.swing.renderer.NumberPercentRenderer;
-import org.graalvm.visualvm.lib.jfluid.utils.Wildcards;
-import org.graalvm.visualvm.lib.profiler.api.ActionsSupport;
-import org.graalvm.visualvm.lib.profiler.api.GoToSource;
-import org.graalvm.visualvm.lib.profiler.api.icons.GeneralIcons;
-import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
-import org.graalvm.visualvm.lib.profiler.api.icons.LanguageIcons;
-import org.graalvm.visualvm.lib.profiler.api.icons.ProfilerIcons;
+import org.graalvm.visualvm.profiling.actions.ProfiledSourceSelection;
+import org.graalvm.visualvm.profiling.actions.ProfilerPopupCustomizer;
+import org.graalvm.visualvm.sampler.truffle.AbstractSamplerSupport;
 import org.graalvm.visualvm.sampler.truffle.memory.MemorySamplerSupport.TruffleClassInfo;
 import org.graalvm.visualvm.sampler.truffle.memory.MemorySamplerSupport.TruffleHeapHistogram;
 import org.openide.util.Exceptions;
@@ -105,8 +105,8 @@ final class MemoryView extends JPanel {
     private final MemorySamplerSupport.HeapDumper heapDumper;
     private final MemorySamplerSupport.SnapshotDumper snapshotDumper;
     
-    private List<TruffleClassInfo> classes = new ArrayList();
-    private List<TruffleClassInfo> baseClasses = new ArrayList(); // Needed to correctly setup table renderers
+    private List<TruffleClassInfo> classes = new ArrayList<>();
+    private List<TruffleClassInfo> baseClasses = new ArrayList<>(); // Needed to correctly setup table renderers
     private long totalBytes, baseTotalBytes = -1;
     private long totalInstances, baseTotalInstances = -1;
     private long totalAllocBytes, baseTotalAllocBytes = -1;
@@ -154,7 +154,7 @@ final class MemoryView extends JPanel {
         boolean diff = lrDeltasButton.isSelected();
         if (diff) {
             if (baseClasses == null) {
-                baseClasses = new ArrayList(classes);
+                baseClasses = new ArrayList<>(classes);
                 baseTotalBytes = totalBytes;
                 baseTotalInstances = totalInstances;
                 baseTotalAllocBytes = totalAllocBytes;
@@ -231,7 +231,7 @@ final class MemoryView extends JPanel {
 
     private static List<TruffleClassInfo> computeDeltaClasses(Collection<TruffleClassInfo> basis, Collection<TruffleClassInfo> changed) {
 
-        Map<String, DeltaClassInfo> deltaMap = new HashMap((int)(basis.size() * 1.3));
+        Map<String, DeltaClassInfo> deltaMap = new HashMap<>((int)(basis.size() * 1.3));
 
         for (TruffleClassInfo cInfo : basis)
             deltaMap.put(cInfo.getName(), new DeltaClassInfo(cInfo, true));
@@ -242,7 +242,7 @@ final class MemoryView extends JPanel {
             else deltaMap.put(cInfo.getName(), new DeltaClassInfo(cInfo, false));
         }
 
-        return new ArrayList(deltaMap.values());
+        return new ArrayList<>(deltaMap.values());
     }
     
     
@@ -359,7 +359,7 @@ final class MemoryView extends JPanel {
         InputMap inputMap = getInputMap(JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);
         ActionMap actionMap = getActionMap();
         
-        final String filterKey = org.graalvm.visualvm.lib.ui.swing.FilterUtils.FILTER_ACTION_KEY;
+        final String filterKey = FilterUtils.FILTER_ACTION_KEY;
         Action filterAction = new AbstractAction() {
             public void actionPerformed(ActionEvent e) {
                 MemoryView.this.activateFilter();
@@ -549,7 +549,7 @@ final class MemoryView extends JPanel {
         
         ProfiledSourceSelection pss = new ProfiledSourceSelection(application, className, Wildcards.ALLWILDCARD, null);
         
-        List<JMenuItem> menuItems = new ArrayList(customizers.size());
+        List<JMenuItem> menuItems = new ArrayList<>(customizers.size());
         
         for (ProfilerPopupCustomizer customizer : customizers) {
             if (customizer.supportsDataView(ProfilerPopupCustomizer.View.MEMORY, ProfilerPopupCustomizer.Mode.LIVE)) {
