@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  * 
  * This code is free software; you can redistribute it and/or modify it
@@ -54,7 +54,6 @@ import org.graalvm.visualvm.tools.attach.AttachModelFactory;
 import org.graalvm.visualvm.tools.jmx.JmxModel;
 import org.graalvm.visualvm.tools.jmx.JmxModelFactory;
 import org.graalvm.visualvm.tools.jmx.JvmMXBeans;
-import org.graalvm.visualvm.tools.jmx.JvmMXBeansFactory;
 import org.graalvm.visualvm.uisupport.HTMLLabel;
 import org.graalvm.visualvm.uisupport.HTMLTextArea;
 import java.awt.Dimension;
@@ -94,6 +93,7 @@ import org.graalvm.visualvm.lib.jfluid.results.memory.SampledMemoryResultsSnapsh
 import org.graalvm.visualvm.lib.profiler.LoadedSnapshot;
 import org.graalvm.visualvm.lib.profiler.ResultsManager;
 import org.graalvm.visualvm.lib.profiler.api.ProfilerDialogs;
+import org.graalvm.visualvm.profiling.presets.ProfilerPreset;
 import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
 import org.openide.util.ImageUtilities;
@@ -125,7 +125,7 @@ final class SamplerImpl {
     private AbstractSamplerSupport memorySampler;
     private MemorySettingsSupport memorySettings;
     
-    private DefaultComboBoxModel selectorModel;
+    private DefaultComboBoxModel<ProfilerPreset> selectorModel;
     private List<PresetSelector> allSelectors;
 
     private DataViewComponent dvc;
@@ -133,10 +133,14 @@ final class SamplerImpl {
     private DataViewComponent.DetailsView[] currentViews;
 
     private State state = State.TRANSITION;
+    private SamplerArguments.Request startRequest;
+    private SamplerParameters settingsRequest;
 
 
-    SamplerImpl(Application application) {
+    SamplerImpl(Application application, SamplerArguments.Request startRequest, SamplerParameters settingsRequest) {
         this.application = application;
+        this.startRequest = startRequest;
+        this.settingsRequest = settingsRequest;
         
         cpuSettings = new CPUSettingsSupport() {
             public boolean presetValid() {
@@ -158,9 +162,35 @@ final class SamplerImpl {
         };
     }
     
+    
+    void startCPU(SamplerParameters parameters) {
+        if (parameters != null && !parameters.isEmpty()) cpuSettings.setSettings(parameters);
+        if (!cpuProfilingSupported) startRequest = SamplerArguments.Request.CPU; // likely not initialized yet, perform lazily
+        else if (cpuButton != null && cpuButton.isEnabled() && !cpuButton.isSelected()) cpuButton.doClick();
+    }
+    
+    void startMemory(SamplerParameters parameters) {
+        if (parameters != null && !parameters.isEmpty()) memorySettings.setSettings(parameters);
+        if (!memoryProfilingSupported) startRequest = SamplerArguments.Request.MEMORY; // likely not initialized yet, perform lazily
+        else if (memoryButton != null && memoryButton.isEnabled() && !memoryButton.isSelected()) memoryButton.doClick();
+    }
+    
+    void takeSnapshot(boolean openView) {
+        if (cpuSampler != null && State.CPU.equals(getState())) {
+            cpuSampler.takeSnapshot(openView);
+        } else if (memorySampler != null && State.MEMORY.equals(getState())) {
+            memorySampler.takeSnapshot(openView);
+        }
+    }
+    
+    void stop() {
+        if (stopButton != null && stopButton.isEnabled()) stopButton.doClick();
+    }
+    
+    
     private PresetSelector createSelector(Runnable presetSynchronizer) {
-        if (selectorModel == null) selectorModel = new DefaultComboBoxModel();
-        if (allSelectors == null) allSelectors = new ArrayList();
+        if (selectorModel == null) selectorModel = new DefaultComboBoxModel<>();
+        if (allSelectors == null) allSelectors = new ArrayList<>();
         PresetSelector selector = ProfilerPresets.getInstance().createSelector(
                                   application, selectorModel, allSelectors, presetSynchronizer);
         allSelectors.add(selector);
@@ -592,6 +622,7 @@ final class SamplerImpl {
                         refreshSummary();
                         updateButtons();
                         updateSettings();
+                        if (SamplerArguments.Request.CPU.equals(startRequest)) startCPU(settingsRequest);
                     }
                 });
             }
@@ -626,7 +657,7 @@ final class SamplerImpl {
                             });
                             return;
                         }
-                        if (!JvmFactory.getJVMFor(application).isAttachable()) {
+                        if (!jvm.isAttachable()) {
                             SwingUtilities.invokeLater(new Runnable() {
                                 public void run() {
                                     memoryStatus = NbBundle.getMessage(SamplerImpl.class,
@@ -641,7 +672,7 @@ final class SamplerImpl {
                             SwingUtilities.invokeLater(new Runnable() {
                                 public void run() {
                                     memoryStatus = NbBundle.getMessage(SamplerImpl.class,
-                                            "MSG_Unavailable_connect_log"); // NOI18N
+                                            "MSG_Unavailable_connect_log", VisualVM.getInstance().getLogfileHandle()); // NOI18N
                                     refreshSummary();
                                 }
                             });
@@ -651,7 +682,7 @@ final class SamplerImpl {
                         SwingUtilities.invokeLater(new Runnable() {
                             public void run() {
                                 memoryStatus = NbBundle.getMessage(SamplerImpl.class,
-                                    "MSG_Unavailable_read_log"); // NOI18N
+                                    "MSG_Unavailable_read_log", VisualVM.getInstance().getLogfileHandle()); // NOI18N
                                 refreshSummary();
                             }
                         });
@@ -663,7 +694,7 @@ final class SamplerImpl {
                     SwingUtilities.invokeLater(new Runnable() {
                         public void run() {
                             memoryStatus = NbBundle.getMessage(SamplerImpl.class,
-                                    "MSG_Unavailable_read_log"); // NOI18N
+                                    "MSG_Unavailable_read_log", VisualVM.getInstance().getLogfileHandle()); // NOI18N
                             refreshSummary();
                         }
                     });
@@ -675,7 +706,7 @@ final class SamplerImpl {
                 ThreadsMemory threadsMemory = null;
                 JmxModel jmxModel = JmxModelFactory.getJmxModelFor(application);
                 if (jmxModel != null && jmxModel.getConnectionState() == JmxModel.ConnectionState.CONNECTED) {
-                    JvmMXBeans mxbeans = JvmMXBeansFactory.getJvmMXBeans(jmxModel);
+                    JvmMXBeans mxbeans = jmxModel.getJvmMXBeans();
                     if (mxbeans != null) {
                         memoryBean = mxbeans.getMemoryMXBean();
                         try {
@@ -787,6 +818,7 @@ final class SamplerImpl {
                         refreshSummary();
                         updateButtons();
                         updateSettings();
+                        if (SamplerArguments.Request.MEMORY.equals(startRequest)) startMemory(settingsRequest);
                     }
                 });
             }
@@ -1001,7 +1033,7 @@ final class SamplerImpl {
 
     private static final class OneWayToggleButton extends JToggleButton {
 
-        public OneWayToggleButton(String text) {
+        OneWayToggleButton(String text) {
             super(text);
         }
 
