@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -93,9 +93,9 @@ final class ThreadsCPUView extends JPanel {
         this.refresher = refresher;
         this.threadDumper = threadDumper;
         
-        threads = Collections.EMPTY_LIST;
-        threadCPUInfo = Collections.EMPTY_LIST;
-        threadCPUInfoPerSec = Collections.EMPTY_LIST;
+        threads = Collections.emptyList();
+        threadCPUInfo = Collections.emptyList();
+        threadCPUInfoPerSec = Collections.emptyList();
         
         initComponents();
         
@@ -405,7 +405,7 @@ final class ThreadsCPUView extends JPanel {
         JComponent panel = getBottomPanel();
         
         if (filterPanel == null) {
-            filterPanel = FilterUtils.createFilterPanel(table, null);
+            filterPanel = FilterUtils.createFilterPanel(table);
             panel.add(filterPanel);
             Container parent = panel.getParent();
             parent.invalidate();
