@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  * 
  * This code is free software; you can redistribute it and/or modify it
@@ -109,11 +109,8 @@ final class MemoryView extends JPanel {
     private final MemorySamplerSupport.HeapDumper heapDumper;
     private final MemorySamplerSupport.SnapshotDumper snapshotDumper;
     
-    private List<ClassInfo> classes = new ArrayList();
-    private List<ClassInfo> baseClasses = new ArrayList(); // Needed to correctly setup table renderers
-//    private int totalClasses = -1;
-    private long totalBytes, baseTotalBytes = -1;
-    private long totalInstances, baseTotalInstances = -1;
+    private List<ClassInfo> classes = new ArrayList<>();
+    private List<ClassInfo> baseClasses = new ArrayList<>(); // Needed to correctly setup table renderers
 
 
     MemoryView(Application application, AbstractSamplerSupport.Refresher refresher, int mode,
@@ -153,46 +150,43 @@ final class MemoryView extends JPanel {
     
     void refresh(HeapHistogram histogram) {
         if (histogram == null || isPaused()) return;
+        long bytesMaxValue = 0;
+        long instancesMaxValue = 0;
         forceRefresh = false;
         
         boolean diff = lrDeltasButton.isSelected();
         if (diff) {
             if (baseClasses == null) {
-                baseClasses = new ArrayList(classes);
-                baseTotalBytes = totalBytes;
-                baseTotalInstances = totalInstances;
+                baseClasses = new ArrayList<>(classes);
             }
 
             Collection<ClassInfo> newClasses = getHistogram(histogram);
             classes = computeDeltaClasses(baseClasses, newClasses);
 
-//            totalClasses = baseClasses.size() - newClasses.size();
-            totalBytes = getTotalBytes(histogram) - baseTotalBytes;
-            totalInstances = getTotalInstances(histogram) - baseTotalInstances;
-
             long maxAbsDiffBytes = 0;
-            for (ClassInfo cInfo : classes)
+            long maxAbsDiffInstances = 0;
+            for (ClassInfo cInfo : classes) {
                 maxAbsDiffBytes = Math.max(maxAbsDiffBytes, Math.abs(cInfo.getBytes()));
-            
+                maxAbsDiffInstances = Math.max(maxAbsDiffInstances, Math.abs(cInfo.getInstancesCount()));
+            }
+            bytesMaxValue = maxAbsDiffBytes;
+            instancesMaxValue = maxAbsDiffInstances;
         } else {
             if (baseClasses != null) {
                 baseClasses = null;
-                baseTotalBytes = -1;
-                baseTotalInstances = -1;
             }
             classes.clear();
             classes.addAll(getHistogram(histogram));
 
-//            totalClasses = classes.size();
-            totalBytes = getTotalBytes(histogram);
-            totalInstances = getTotalInstances(histogram);
+            bytesMaxValue = getTotalBytes(histogram);
+            instancesMaxValue = getTotalInstances(histogram);
         }
         
         renderers[0].setDiffMode(diff);
-        renderers[0].setMaxValue(totalBytes);
+        renderers[0].setMaxValue(bytesMaxValue);
         
         renderers[1].setDiffMode(diff);
-        renderers[1].setMaxValue(totalInstances);
+        renderers[1].setMaxValue(instancesMaxValue);
 
         tableModel.fireTableDataChanged();
 
@@ -219,7 +213,7 @@ final class MemoryView extends JPanel {
         heapdumpButton.setEnabled(false);
     }
 
-    private Collection getHistogram(HeapHistogram histogram) {
+    private Collection<ClassInfo> getHistogram(HeapHistogram histogram) {
         if (mode == MODE_HEAP) return histogram.getHeapHistogram();
         if (mode == MODE_PERMGEN) return histogram.getPermGenHistogram();
         return null;
@@ -239,7 +233,7 @@ final class MemoryView extends JPanel {
 
     private static List<ClassInfo> computeDeltaClasses(Collection<ClassInfo> basis, Collection<ClassInfo> changed) {
 
-        Map<String, DeltaClassInfo> deltaMap = new HashMap((int)(basis.size() * 1.3));
+        Map<String, DeltaClassInfo> deltaMap = new HashMap<>((int)(basis.size() * 1.3));
 
         for (ClassInfo cInfo : basis)
             deltaMap.put(cInfo.getName(), new DeltaClassInfo(cInfo, true));
@@ -250,7 +244,7 @@ final class MemoryView extends JPanel {
             else deltaMap.put(cInfo.getName(), new DeltaClassInfo(cInfo, false));
         }
 
-        return new ArrayList(deltaMap.values());
+        return new ArrayList<>(deltaMap.values());
     }
     
     
@@ -362,7 +356,7 @@ final class MemoryView extends JPanel {
         InputMap inputMap = getInputMap(JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);
         ActionMap actionMap = getActionMap();
         
-        final String filterKey = org.graalvm.visualvm.lib.ui.swing.FilterUtils.FILTER_ACTION_KEY;
+        final String filterKey = FilterUtils.FILTER_ACTION_KEY;
         Action filterAction = new AbstractAction() {
             public void actionPerformed(ActionEvent e) {
                 MemoryView.this.activateFilter();
@@ -477,7 +471,7 @@ final class MemoryView extends JPanel {
         };
         gcButton.setToolTipText(NbBundle.getMessage(MemoryView.class, "TOOLTIP_Gc")); // NOI18N
         gcButton.setOpaque(false);
-        gcButton.setEnabled(heapDumper != null);
+        gcButton.setEnabled(memoryBean != null);
         toolbar.add(gcButton);
         
         heapdumpButton = new JButton(NbBundle.getMessage(MemoryView.class, "LBL_HeapDump")) { // NOI18N
@@ -516,7 +510,7 @@ final class MemoryView extends JPanel {
         JComponent panel = getBottomPanel();
         
         if (filterPanel == null) {
-            filterPanel = FilterUtils.createFilterPanel(table, null);
+            filterPanel = FilterUtils.createFilterPanel(table);
             panel.add(filterPanel);
             Container parent = panel.getParent();
             parent.invalidate();
@@ -554,7 +548,7 @@ final class MemoryView extends JPanel {
         
         ProfiledSourceSelection pss = new ProfiledSourceSelection(application, className, Wildcards.ALLWILDCARD, null);
         
-        List<JMenuItem> menuItems = new ArrayList(customizers.size());
+        List<JMenuItem> menuItems = new ArrayList<>(customizers.size());
         
         for (ProfilerPopupCustomizer customizer : customizers) {
             if (customizer.supportsDataView(ProfilerPopupCustomizer.View.MEMORY, ProfilerPopupCustomizer.Mode.LIVE)) {
