@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -159,6 +159,17 @@ public abstract class JmxModel extends Model {
      */
     public abstract JMXServiceURL getJMXServiceURL();
 
+    /**
+     * <p>Method for obtaining the {@link JvmMXBeans} for
+     * the given {@link JmxModel}.</p>
+     *
+     * @return a {@link JvmMXBeans} instance containing the MXBean
+     * proxies for the Java platform MXBeans backed by the supplied
+     * {@link JmxModel}. No MBean caching is applied on the supplied
+     * {@link JmxModel}.
+     */
+    public abstract JvmMXBeans getJvmMXBeans();
+
     /**
      * Returns the current system properties in the target Application.
      *
